MSG_HASH(
      MSG_COMPILER,
      "Compilateur"
      )
MSG_HASH(
      MSG_UNKNOWN_COMPILER,
      "Compilateur inconnu"
      )
MSG_HASH(
      MSG_DEVICE_DISCONNECTED_FROM_PORT,
      "Périphérique déconnecté du port"
      )
MSG_HASH(
      MSG_UNKNOWN_NETPLAY_COMMAND_RECEIVED,
      "Commande réseau inconnue reçue"
      )
MSG_HASH(
      MSG_FILE_ALREADY_EXISTS_SAVING_TO_BACKUP_BUFFER,
      "Fichier déjà existant. Sauvegarde dans un tampon de backup"
      )
MSG_HASH(
      MSG_GOT_CONNECTION_FROM,
      "Connexion reçue depuis : \"%s\""
      )
MSG_HASH(
      MSG_GOT_CONNECTION_FROM_NAME,
      "Connexion reçue de : \"%s (%s)\""
      )
MSG_HASH(
      MSG_PUBLIC_ADDRESS,
      "Adresse publique"
      )
MSG_HASH(
      MSG_NO_ARGUMENTS_SUPPLIED_AND_NO_MENU_BUILTIN,
      "Aucun paramètre fourni et pas de menu intégré, affichage de l'aide..."
      )
MSG_HASH(
      MSG_SETTING_DISK_IN_TRAY,
      "Disque inséré dans le lecteur"
      )
MSG_HASH(
      MSG_WAITING_FOR_CLIENT,
      "En attente d'un client ..."
      )
MSG_HASH(
      MSG_NETPLAY_YOU_HAVE_LEFT_THE_GAME,
      "Vous avez quitté le jeu"
      )
MSG_HASH(
      MSG_NETPLAY_YOU_HAVE_JOINED_AS_PLAYER_N,
      "Vous avez rejoint le jeu en tant que joueur %u"
      )
MSG_HASH(
      MSG_NETPLAY_ENDIAN_DEPENDENT,
      "Ce cœur ne supporte pas le jeu en réseau inter-architectures entre ces systèmes"
      )
MSG_HASH(
      MSG_NETPLAY_PLATFORM_DEPENDENT,
      "Ce cœur ne supporte pas le jeu en réseau inter-architectures"
      )
MSG_HASH(
      MSG_NETPLAY_ENTER_PASSWORD,
      "Entrez le mot de passe du serveur de netplay:"
      )
MSG_HASH(
      MSG_NETPLAY_INCORRECT_PASSWORD,
      "Mot de passe incorrect"
      )
MSG_HASH(
      MSG_NETPLAY_SERVER_NAMED_HANGUP,
      "\"%s\" s'est déconnecté"
      )
MSG_HASH(
      MSG_NETPLAY_SERVER_HANGUP,
      "Un client de jeu en réseau s'est déconnecté"
      )
MSG_HASH(
      MSG_NETPLAY_CLIENT_HANGUP,
      "Netplay déconnecté"
      )
MSG_HASH(
      MSG_NETPLAY_CANNOT_PLAY_UNPRIVILEGED,
      "Vous n'avez pas la permission de jouer"
      )
MSG_HASH(
      MSG_NETPLAY_CANNOT_PLAY_NO_SLOTS,
      "Aucune place de libre pour jouer"
      )
MSG_HASH(
      MSG_NETPLAY_CANNOT_PLAY,
      "Impossible de basculer en mode jeu"
      )
MSG_HASH(
      MSG_NETPLAY_PEER_PAUSED,
      "Le joueur \"%s\" à mis en pause"
      )
MSG_HASH(
      MSG_NETPLAY_CHANGED_NICK,
      "Votre pseudo est maintenant \"%s\""
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_SHARED_CONTEXT,
      "Donne aux cœurs bénéficiant de l'accélération graphique leur propre contexte. Évite d'avoir à supposer des changements d'état matériel entre deux images."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_MENU_SETTINGS,
      "Ajuster les réglages et l'apparence du menu."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_HARD_SYNC,
      "Synchronisation 'hard' du CPU et du GPU. Réduis la latence mais affecte les performances."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_THREADED,
      "Améliore les performances au prix d'une certaine latence et d'à-coups visuels accrus. À n'utiliser que si vous ne pouvez pas faire autrement."
      )
MSG_HASH(
      MSG_AUDIO_VOLUME,
      "Volume sonore"
      )
MSG_HASH(
      MSG_AUTODETECT,
      "Détection automatique"
      )
MSG_HASH(
      MSG_AUTOLOADING_SAVESTATE_FROM,
      "Chargement auto d'une sauvegarde instantanée depuis"
      )
MSG_HASH(
      MSG_CAPABILITIES,
      "Capacités"
      )
MSG_HASH(
      MSG_CONNECTING_TO_NETPLAY_HOST,
      "Connexion à l'hôte"
      )
MSG_HASH(
      MSG_CONNECTING_TO_PORT,
      "Connexion au port"
      )
MSG_HASH(
      MSG_CONNECTION_SLOT,
      "Emplacement de connexion"
      )
MSG_HASH(
      MSG_SORRY_UNIMPLEMENTED_CORES_DONT_DEMAND_CONTENT_NETPLAY,
      "Désolé, non implémenté: les cœurs qui tournent sans contenu ne peuvent pas participer au jeu en réseau."
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ACCOUNTS_CHEEVOS_PASSWORD,
      "Mot de passe"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ACCOUNTS_CHEEVOS_SETTINGS,
      "Comptes Cheevos"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ACCOUNTS_CHEEVOS_USERNAME,
      "Identifiant"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ACCOUNTS_LIST,
      "Comptes"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ACCOUNTS_LIST_END,
      "Liste des comptes"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ACCOUNTS_RETRO_ACHIEVEMENTS,
      "Trophées"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ACHIEVEMENT_LIST,
      "Liste des trophées"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ACHIEVEMENT_LIST_HARDCORE,
      "Liste des trophées (hardcore)"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ADD_CONTENT_LIST,
      "Scanner du contenu"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONFIGURATIONS_LIST,
      "Configurations"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ADD_TAB,
      "Importer du contenu"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_NETPLAY_TAB,
      "Salons de jeu en réseau"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ASK_ARCHIVE,
      "Demander"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ASSETS_DIRECTORY,
      "Assets"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_BLOCK_FRAMES,
      "Block Frames"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_DEVICE,
      "Périphérique audio"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_DRIVER,
      "Pilote audio"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_DSP_PLUGIN,
      "Module DSP audio"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_ENABLE,
      "Activer le son"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_FILTER_DIR,
      "Filtres audio"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_TURBO_DEADZONE_LIST,
      "Turbo/Deadzone"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_LATENCY,
      "Latence audio (ms)"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_MAX_TIMING_SKEW,
      "Limite max de l'ajustement"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_MUTE,
      "Sourdine"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_OUTPUT_RATE,
      "Fréquence de sortie (Hz)"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_RATE_CONTROL_DELTA,
      "Contrôle du taux dynamique"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_RESAMPLER_DRIVER,
      "Pilote de ré-échantillonnage audio"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_SETTINGS,
      "Audio"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_SYNC,
      "Synchroniser le son"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_VOLUME,
      "Volume sonore (dB)"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_WASAPI_EXCLUSIVE_MODE,
      "Mode exclusif WASAPI"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_WASAPI_FLOAT_FORMAT,
      "Format de flottants WASAPI"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_WASAPI_SH_BUFFER_LENGTH,
      "Taille du tampon partagé WASAPI"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUTOSAVE_INTERVAL,
      "Intervalle de sauvegarde SaveRAM"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUTO_OVERRIDES_ENABLE,
      "Charger les surcharges de configuration automatiquement"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUTO_REMAPS_ENABLE,
      "Charger les fichiers de remappage automatiquement"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUTO_SHADERS_ENABLE,
      "Charger les pré-réglages de shaders automatiquement"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_BACK,
      "Retour"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_CONFIRM,
      "Confirmer"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_INFO,
      "Information"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_QUIT,
      "Quitter"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_SCROLL_DOWN,
      "Défilement vers le bas"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_SCROLL_UP,
      "Défilement vers le haut"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_START,
      "Démarrer"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_TOGGLE_KEYBOARD,
      "Basculer sur le clavier"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_TOGGLE_MENU,
      "Basculer sur le menu"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS,
      "Contrôles de base du menu"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS_CONFIRM,
      "Confirmer/OK"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS_INFO,
      "Information"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS_QUIT,
      "Quitter"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS_SCROLL_UP,
      "Défilement vers le haut"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS_START,
      "Défauts"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS_TOGGLE_KEYBOARD,
      "Basculer sur le clavier"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS_TOGGLE_MENU,
      "Basculer sur le Menu"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BLOCK_SRAM_OVERWRITE,
      "Ne pas écraser la SaveRAM en chargeant la sauvegarde instantanée"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BLUETOOTH_ENABLE,
      "Activer le Bluetooth"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BUILDBOT_ASSETS_URL,
      "URL du buildbot des assets"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CACHE_DIRECTORY,
      "Cache"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CAMERA_ALLOW,
      "Autoriser l'accès à la caméra"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CAMERA_DRIVER,
      "Autoriser la caméra"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEAT,
      "Triche"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEAT_APPLY_CHANGES,
      "Appliquer les changements"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEAT_DATABASE_PATH,
      "Fichier de triche"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEAT_FILE,
      "Fichier de triche"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEAT_FILE_LOAD,
      "Charger un fichier de triche"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEAT_FILE_SAVE_AS,
      "Enregistrer le fichier de triche sous"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEAT_NUM_PASSES,
      "Nombre de passages"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_DESCRIPTION,
      "Description"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_HARDCORE_MODE_ENABLE,
      "Trophées en mode hardcore"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_LOCKED_ACHIEVEMENTS,
      "Trophées verrouillés :"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_LOCKED_ENTRY,
      "Verrouillé"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_SETTINGS,
      "Trophées"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_TEST_UNOFFICIAL,
      "Tester les trophées non officiels"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_UNLOCKED_ACHIEVEMENTS,
      "Trophées déverrouillés :"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_UNLOCKED_ENTRY,
      "Déverrouillés"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CLOSE_CONTENT,
      "Fermer le contenu"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONFIG,
      "Configuration"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONFIGURATIONS,
      "Charger une configuration"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONFIGURATION_SETTINGS,
      "Configuration"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONFIG_SAVE_ON_EXIT,
      "Sauvegarder la configuration en quittant"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONTENT_COLLECTION_LIST,
      "Collections"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONTENT_DATABASE_DIRECTORY,
      "Base de données"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONTENT_DIR,
      "Contenu"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONTENT_HISTORY_SIZE,
      "Taille de l'historique")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PLAYLIST_ENTRY_REMOVE,
      "Autoriser la suppression d'entées")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SETTINGS,
      "Menu rapide")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_ASSETS_DIR,
      "Téléchargements")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_ASSETS_DIRECTORY,
      "Téléchargements")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_CHEAT_OPTIONS,
      "Fichiers de triche")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_COUNTERS,
      "Compteurs du cœur")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_ENABLE,
      "Afficher le nom du cœur chargé")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFORMATION,
      "Informations sur le cœur")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_AUTHORS,
      "Auteurs")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_CATEGORIES,
      "Catégories")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_CORE_LABEL,
      "Label du cœur")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_CORE_NAME,
      "Nom du cœur")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_FIRMWARE,
      "Firmware(s)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_LICENSES,
      "Licence(s)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_PERMISSIONS,
      "Permissions")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_SUPPORTED_EXTENSIONS,
      "Extensions supportées")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_SYSTEM_MANUFACTURER,
      "Fabricant du système")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_SYSTEM_NAME,
      "Nom du système")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INPUT_REMAPPING_OPTIONS,
      "Remappage des contrôles")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_LIST,
      "Charger un cœur")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_OPTIONS,
      "Options")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_SETTINGS,
      "Cœur")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_SET_SUPPORTS_NO_CONTENT_ENABLE,
      "Démarrer les cœurs automatiquement")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_UPDATER_AUTO_EXTRACT_ARCHIVE,
      "Extraire automatiquement les archives téléchargées")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_UPDATER_BUILDBOT_URL,
      "URL du buildbot des cœurs")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_UPDATER_LIST,
      "Mises à jour des cœurs")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_UPDATER_SETTINGS,
      "Mises à jour")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CPU_ARCHITECTURE,
      "Architecture du CPU :")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CPU_CORES,
      "Cœurs du CPU :")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CURSOR_DIRECTORY,
      "Curseur")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CURSOR_MANAGER,
      "Gestionnaire de curseurs")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CUSTOM_RATIO,
      "Rapport d'aspect custom")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_MANAGER,
      "Gestionnaire de bases de données")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_SELECTION,
      "Sélection de la base de données")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DELETE_ENTRY,
      "Supprimer")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FAVORITES,
      "Dossier de démarrage")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DIRECTORY_CONTENT,
      "<Dossier du contenu>")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DIRECTORY_DEFAULT,
      "<Par défaut>")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DIRECTORY_NONE,
      "<Aucun>")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DIRECTORY_NOT_FOUND,
      "Dossier non trouvé.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DIRECTORY_SETTINGS,
      "Dossier")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DISK_CYCLE_TRAY_STATUS,
      "État du lecteur de disque")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DISK_IMAGE_APPEND,
      "Ajouter une image de disque")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DISK_INDEX,
      "Numéro du disque")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DISK_OPTIONS,
      "Contrôle du disque")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DONT_CARE,
      "Peu importe")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DOWNLOADED_FILE_DETECT_CORE_LIST,
      "Téléchargements")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DOWNLOAD_CORE,
      "Télécharger un cœur...")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DOWNLOAD_CORE_CONTENT,
      "Télécharger du contenu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DPI_OVERRIDE_ENABLE,
      "DPI personnalisé")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DPI_OVERRIDE_VALUE,
      "Valeur du DPI personnalisé")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DRIVER_SETTINGS,
      "Pilote")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DUMMY_ON_CORE_SHUTDOWN,
      "Charger un cœur factice après fermeture")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CHECK_FOR_MISSING_FIRMWARE,
      "Vérifier la présence des firmwares au chargement")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DYNAMIC_WALLPAPER,
      "Fonds d'écran dynamique")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DYNAMIC_WALLPAPERS_DIRECTORY,
      "Fonds d'écran dynamique")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CHEEVOS_ENABLE,
      "Activer les trophées")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ENTRY_HOVER_COLOR,
      "Couleur de l'entrée menu active")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ENTRY_NORMAL_COLOR,
      "Couleur des entrées du menu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FALSE,
      "Faux")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FASTFORWARD_RATIO,
      "Vitesse de jeu maximum")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FPS_SHOW,
      "Afficher le nombre d'images/s")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FRAME_THROTTLE_ENABLE,
      "Limiter la vitesse d'exécution")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FRAME_THROTTLE_SETTINGS,
      "Vitesse d'affichage")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FRONTEND_COUNTERS,
      "Compteurs du Frontend")
MSG_HASH(MENU_ENUM_LABEL_VALUE_GAME_SPECIFIC_OPTIONS,
      "Charger automatiquement les configuration du cœur par jeux")
MSG_HASH(MENU_ENUM_LABEL_VALUE_GAME_SPECIFIC_OPTIONS_CREATE,
      "Créer un fichier de configuration du cœur pour ce jeu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_GAME_SPECIFIC_OPTIONS_IN_USE,
      "Fichier de configuration du jeu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HELP,
      "Aide")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HELP_AUDIO_VIDEO_TROUBLESHOOTING,
      "Dépannage audio/vidéo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HELP_CHANGE_VIRTUAL_GAMEPAD,
      "Utiliser un overlay de manette virtuelle")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HELP_CONTROLS,
      "Contrôles de base du menu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HELP_LIST,
      "Aide")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HELP_LOADING_CONTENT,
      "Chargement du contenu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HELP_SCANNING_CONTENT,
      "Scan de contenus")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HELP_WHAT_IS_A_CORE,
      "Qu'est-ce qu'un cœur ?")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HISTORY_LIST_ENABLE,
      "Activer l'historique")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HISTORY_TAB,
      "Historique")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HORIZONTAL_MENU,
      "Menu horizontal")
MSG_HASH(MENU_ENUM_LABEL_VALUE_IMAGES_TAB,
      "Image")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INFORMATION,
      "Informations")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INFORMATION_LIST,
      "Informations")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ADC_TYPE,
      "Type Analogique vers Numérique")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ALL_USERS_CONTROL_MENU,
      "Tous les utilisateurs contrôlent le menu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_LEFT_X,
      "Analogique gauche X")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_LEFT_X_MINUS,
      "Analogique gauche X- (gauche)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_LEFT_X_PLUS,
      "Analogique gauche X+ (droite)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_LEFT_Y,
      "Analogique gauche Y")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_LEFT_Y_MINUS,
      "Analogique gauche Y- (haut)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_LEFT_Y_PLUS,
      "Analogique gauche Y+ (bas)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_RIGHT_X,
      "Analogique droit X")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_RIGHT_X_MINUS,
      "Analogique droit X- (gauche)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_RIGHT_X_PLUS,
      "Analogique droit X+ (droite)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_RIGHT_Y,
      "Right Analog Y")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_RIGHT_Y_MINUS,
      "Analogique droit Y- (haut)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_RIGHT_Y_PLUS,
      "Analogique droit Y+ (bas)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_TRIGGER,
      "Gun Trigger")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_RELOAD,
      "Gun Reload")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_AUX_A,
      "Gun Aux A")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_AUX_B,
      "Gun Aux B")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_AUX_C,
      "Gun Aux C")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_START,
      "Gun Start")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_SELECT,
      "Gun Select")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_DPAD_UP,
      "Gun D-pad Up")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_DPAD_DOWN,
      "Gun D-pad Down")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_DPAD_LEFT,
      "Gun D-pad Left")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_DPAD_RIGHT,
      "Gun D-pad Right")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_AUTODETECT_ENABLE,
      "Activer l'autoconfiguration")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_AXIS_THRESHOLD,
      "Seuil des axes analogiques")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_INPUT_SWAP_OK_CANCEL,
      "Inverser les boutons OK et Annuler dans le menu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_BIND_ALL,
      "Tout assigner")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_BIND_DEFAULT_ALL,
      "Tour assigner par défaut")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_BIND_TIMEOUT,
      "Délai d'assignation")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_DESCRIPTOR_HIDE_UNBOUND,
      "Cacher les labels ne correspondant à rien sur la manette du cœur")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_DESCRIPTOR_LABEL_SHOW,
      "Afficher les labels des manettes du cœur")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_DEVICE_INDEX,
      "Index du périphérique")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_DEVICE_TYPE,
      "Type de périphérique")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_INDEX,
      "Index de souris")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_DRIVER,
      "Pilote des entrées")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_DUTY_CYCLE,
      "Rapport de cycle")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_HOTKEY_BINDS,
      "Raccourcis d'entrées")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ICADE_ENABLE,
      "Activer le mapping manette/clavier")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_A,
      "Bouton A (droite)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_B,
      "Bouton B (bas)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_DOWN,
      "Croix bas")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_L2,
      "Bouton L2 (gâchette)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_L3,
      "Bouton L3 (pouce)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_L,
      "Bouton L (épaule)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_LEFT,
      "Croix gauche")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_R2,
      "Bouton R2 (gachette)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_R3,
      "Bouton R3 (pouce)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_R,
      "Bouton R (épaule)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_RIGHT,
      "Croix droite")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_SELECT,
      "Bouton select")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_START,
      "Bouton start")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_UP,
      "Croix haut")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_X,
      "Bouton X (haut)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_Y,
      "Bouton Y (gauche)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_KEY,
      "(Touche : %s)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_LEFT,
      "Souris 1")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_RIGHT,
      "Souris 2")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_MIDDLE,
      "Souris 3")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_BUTTON4,
      "Souris 4")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_BUTTON5,
      "Souris 5")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_WHEEL_UP,
      "Molette haut")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_WHEEL_DOWN,
      "Molette bas")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_HORIZ_WHEEL_UP,
      "Molette gauche")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_HORIZ_WHEEL_DOWN,
      "Molette droite")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_KEYBOARD_GAMEPAD_MAPPING_TYPE,
      "Type de mappage manette/clavier")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MAX_USERS,
      "Nombre maximum d'utilisateurs")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MENU_ENUM_TOGGLE_GAMEPAD_COMBO,
      "Combinaison pour afficher le menu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_CHEAT_INDEX_MINUS,
      "Index de triche -")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_CHEAT_INDEX_PLUS,
      "Index de triche +")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_CHEAT_TOGGLE,
      "Activer/désactiver la triche")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_DISK_EJECT_TOGGLE,
      "Insérer/retirer un disque")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_DISK_NEXT,
      "Disque suivant")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_DISK_PREV,
      "Disque précédant")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_ENABLE_HOTKEY,
      "Activer les raccourcis")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_FAST_FORWARD_HOLD_KEY,
      "Touche maintiens d'avance rapide")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_FAST_FORWARD_KEY,
      "Touche ON/OFF d'avance rapide")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_FRAMEADVANCE,
      "Saut d'image")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_FULLSCREEN_TOGGLE_KEY,
      "Plein écran")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_GRAB_MOUSE_TOGGLE,
      "Touche de capture de la souris")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_GAME_FOCUS_TOGGLE,
      "Touche de focus du jeu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_LOAD_STATE_KEY,
      "Charger un état")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_MENU_TOGGLE,
      "Afficher le menu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_MOVIE_RECORD_TOGGLE,
      "Activer l'enregistrement")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_MUTE,
      "Sourdine")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_NETPLAY_GAME_WATCH,
      "Changer de mode joueur/spectateur")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_OSK,
      "Afficher le clavier virtuel")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_OVERLAY_NEXT,
      "Overlay suivant")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_PAUSE_TOGGLE,
      "Pause")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_QUIT_KEY,
      "Quitter RetroArch")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_RESET,
      "Redémarrer le jeu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_REWIND,
      "Retour rapide")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_SAVE_STATE_KEY,
      "Sauvegarder l'état")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_SCREENSHOT,
      "Prendre une capture d'écran")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_SHADER_NEXT,
      "Shader suivant")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_SHADER_PREV,
      "Shader précédent")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_SLOWMOTION_HOLD_KEY,
      "Ralenti")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_STATE_SLOT_MINUS,
      "Emplacement de sauvegarde instantanée -")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_STATE_SLOT_PLUS,
      "Emplacement de sauvegarde instantanée +")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_VOLUME_DOWN,
      "Volume -")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_VOLUME_UP,
      "Volume +")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_OVERLAY_ENABLE,
      "Activer les overlays")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_OVERLAY_HIDE_IN_MENU,
      "Cacher l'overlay dans le menu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_POLL_TYPE_BEHAVIOR,
      "Comportement du poll")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_POLL_TYPE_BEHAVIOR_EARLY,
      "Précoce")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_POLL_TYPE_BEHAVIOR_LATE,
      "Tardif")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_POLL_TYPE_BEHAVIOR_NORMAL,
      "Normal")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_PREFER_FRONT_TOUCH,
      "Préférer le tactile frontal")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_REMAPPING_DIRECTORY,
      "Remappages des entrées")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_REMAP_BINDS_ENABLE,
      "Autoriser le remappage des entrées")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_SAVE_AUTOCONFIG,
      "Sauvegarder l'autoconfiguration")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_SETTINGS,
      "Entrées")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_SMALL_KEYBOARD_ENABLE,
      "Activer le clavier minimal")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_TOUCH_ENABLE,
      "Activer l'écran tactile")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_TURBO_ENABLE,
      "Activer le turbo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_TURBO_PERIOD,
      "Durée du turbo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_USER_BINDS,
      "Entrées de l'utilisateur %u")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INTERNAL_STORAGE_STATUS,
      "État du stockage interne")
MSG_HASH(MENU_ENUM_LABEL_VALUE_JOYPAD_AUTOCONFIG_DIR,
      "Profils d'autoconfiguration des entrées")
MSG_HASH(MENU_ENUM_LABEL_VALUE_JOYPAD_DRIVER,
      "Pilote des manettes")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LAKKA_SERVICES,
      "Services")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_CHINESE_SIMPLIFIED,
      "Chinois (Simplifié)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_CHINESE_TRADITIONAL,
      "Chinois (Traditionnel)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_DUTCH,
      "Néerlandais")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_ENGLISH,
      "Anglais")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_ESPERANTO,
      "Espéranto")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_FRENCH,
      "Français")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_GERMAN,
      "Allemand")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_ITALIAN,
      "Italien")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_JAPANESE,
      "Japonais")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_KOREAN,
      "Coréen")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_POLISH,
      "Polonais")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_PORTUGUESE_BRAZIL,
      "Portugais (Brésil)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_PORTUGUESE_PORTUGAL,
      "Portugais (Portugal)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_RUSSIAN,
      "Russe")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_SPANISH,
      "Espagnol")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_VIETNAMESE,
      "Vietnamien")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_ARABIC,
      "Arabe")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LEFT_ANALOG,
      "Analogique gauche")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LIBRETRO_DIR_PATH,
      "Cœurs")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LIBRETRO_INFO_PATH,
      "Informations des cœurs")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LIBRETRO_LOG_LEVEL,
      "Verbosité des journaux des cœurs")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LINEAR,
      "Linéaire")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LOAD_ARCHIVE,
      "Charger l'archive")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LOAD_CONTENT_HISTORY,
      "Récemment ouvert")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LOAD_CONTENT_LIST,
      "Charger du contenu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LOAD_STATE,
      "Charger une sauvegarde instantanée")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LOCATION_ALLOW,
      "Activer la géolocalisation")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LOCATION_DRIVER,
      "Pilote de géolocalisation")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LOGGING_SETTINGS,
      "Journalisation")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LOG_VERBOSITY,
      "Verbosité des journaux")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MAIN_MENU,
      "Menu principal")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MANAGEMENT,
      "Paramètres de la base de donnée")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME,
      "Couleur du thème du menu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME_BLUE,
      "Bleu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME_BLUE_GREY,
      "Bleu gris")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME_DARK_BLUE,
      "Bleu foncé")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME_GREEN,
      "Vert")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME_NVIDIA_SHIELD,
      "Shield")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME_RED,
      "Rouge")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME_YELLOW,
      "Jaune")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_FOOTER_OPACITY,
      "Opacité du pied de page")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_HEADER_OPACITY,
      "Opacité de l'en-tête")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_DRIVER,
      "Pilote de menu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_ENUM_THROTTLE_FRAMERATE,
      "Contrôler la vitesse d'affichage du menu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_FILE_BROWSER_SETTINGS,
      "Réglages")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_LINEAR_FILTER,
      "Filtre linéaire pour le menu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SETTINGS,
      "Appearance")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_WALLPAPER,
      "Fond d'écran")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_WALLPAPER_OPACITY,
      "Opacité de l'arrière plan")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MISSING,
      "Manquant")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MORE,
      "...")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MOUSE_ENABLE,
      "Support de la souris")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MULTIMEDIA_SETTINGS,
      "Multimédia")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MUSIC_TAB,
      "Musique")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NAVIGATION_BROWSER_FILTER_SUPPORTED_EXTENSIONS_ENABLE,
      "Filtre par extensions supportées")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NAVIGATION_WRAPAROUND,
      "Saut-retour")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NEAREST,
      "Au plus proche")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY,
      "Jeu en réseau")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_ALLOW_SLAVES,
      "Autoriser les clients en mode passif")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_CHECK_FRAMES,
      "Délai de resynchronisation du jeu en réseau (en frames)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_INPUT_LATENCY_FRAMES_MIN,
      "Latence d'entrées minimale")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_INPUT_LATENCY_FRAMES_RANGE,
      "Intervalle de latence d'entées")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_DELAY_FRAMES,
      "Netplay Delay Frames")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_DISCONNECT,
      "Déconnexion")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_ENABLE,
      "Activer le jeu en réseau")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_ENABLE_CLIENT,
      "Se connecter à l'hôte distant")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_ENABLE_HOST,
      "Commencer à héberger")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_DISABLE_HOST,
      "Stopper l'hébergement")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_IP_ADDRESS,
      "Adresse du serveur")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_LAN_SCAN_SETTINGS,
      "Scanner le réseau local")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_MODE,
      "Activer le mode client")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_NICKNAME,
      "Pseudonyme")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_PASSWORD,
      "Mot de passe du serveur")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_PUBLIC_ANNOUNCE,
      "Annoncer la partie publiquement")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_REQUIRE_SLAVES,
      "Interdire les clients non passifs")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_SETTINGS,
      "Réglages du jeu en réseau")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_START_AS_SPECTATOR,
      "Mode spectateur")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_STATELESS_MODE,
      "Mode stateless")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_SPECTATE_PASSWORD,
      "Mot de passe spectateurs")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_SPECTATOR_MODE_ENABLE,
      "Mode spectateur")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_TCP_UDP_PORT,
      "Port TCP du jeu en réseau")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_NAT_TRAVERSAL,
      "Traversée du NAT")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETWORK_CMD_ENABLE,
      "Commandes réseau")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETWORK_CMD_PORT,
      "Port des commandes réseau")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETWORK_INFORMATION,
      "Informations réseau")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETWORK_REMOTE_ENABLE,
      "Manette réseau")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETWORK_REMOTE_PORT,
      "Port de base de la manette réseau")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETWORK_SETTINGS,
      "Réseau")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO,
      "Non")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NONE,
      "Aucun(e)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NOT_AVAILABLE,
      "Indisponible")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_ACHIEVEMENTS_TO_DISPLAY,
      "Aucun trophée à afficher.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_CORE,
      "Pas de cœur")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_CORES_AVAILABLE,
      "Aucun cœur disponible.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_CORE_INFORMATION_AVAILABLE,
      "Pas d'informations disponibles.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_CORE_OPTIONS_AVAILABLE,
      "Pas d'options disponibles.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_ENTRIES_TO_DISPLAY,
      "Aucune entrée à afficher.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_HISTORY_AVAILABLE,
      "Aucun historique disponible.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_INFORMATION_AVAILABLE,
      "Pas d'informations disponibles.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_ITEMS,
      "Vide.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_NETPLAY_HOSTS_FOUND,
      "Aucun hôte trouvé.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_NETWORKS_FOUND,
      "Aucun réseau trouvé.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_PERFORMANCE_COUNTERS,
      "Pas de compteurs de performance.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_PLAYLISTS,
      "Pas de playlist.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_PLAYLIST_ENTRIES_AVAILABLE,
      "Playlist vide.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_SETTINGS_FOUND,
      "Pas de réglages trouvés.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_SHADER_PARAMETERS,
      "Aucun paramètre de shader.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OFF,
      "OFF")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ON,
      "ON")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ONLINE,
      "En ligne")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ONLINE_UPDATER,
      "Mises à jour")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ONSCREEN_DISPLAY_SETTINGS,
      "Affichage à l'écran")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ONSCREEN_OVERLAY_SETTINGS,
      "Overlay à l'écran")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ONSCREEN_NOTIFICATIONS_SETTINGS,
      "Notifications")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OPEN_ARCHIVE,
      "Parcourir l'archive")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OPTIONAL,
      "Optionnel")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OVERLAY,
      "Overlay")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OVERLAY_AUTOLOAD_PREFERRED,
      "Charger l'overlay préféré automatiquement")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OVERLAY_DIRECTORY,
      "Overlays")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OVERLAY_OPACITY,
      "Opacité de l'overlay")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OVERLAY_PRESET,
      "Transparence d'overlay")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OVERLAY_SCALE,
      "Zoom de l'overlay")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OVERLAY_SETTINGS,
      "Overlays")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PAL60_ENABLE,
      "Utiliser le mode PAL60")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PARENT_DIRECTORY,
      "Dossier parent")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PAUSE_LIBRETRO,
      "Mettre le jeu en pause quand le menu est activé")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PAUSE_NONACTIVE,
      "Ne pas fonctionner en arrière-plan")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PERFCNT_ENABLE,
      "Compteurs de performance")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PLAYLISTS_TAB,
      "Playlists")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PLAYLIST_DIRECTORY,
      "Playlists")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PLAYLIST_SETTINGS,
      "Playlists")
MSG_HASH(MENU_ENUM_LABEL_VALUE_POINTER_ENABLE,
      "Support du pavé tactile")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PORT,
      "Port")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PRESENT,
      "Présent")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PRIVACY_SETTINGS,
      "Confidentialité")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUIT_RETROARCH,
      "Quitter RetroArch")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_ANALOG,
      "Support de l'analogique")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_BBFC_RATING,
      "Note BBFC")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_CERO_RATING,
      "Note CERO")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_COOP,
      "Support du co-op")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_CRC32,
      "CRC32")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_DESCRIPTION,
      "Description")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_DEVELOPER,
      "Développeur")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_EDGE_MAGAZINE_ISSUE,
      "Numéro du magazine Edge")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_EDGE_MAGAZINE_RATING,
      "Note du magazine Edge")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_EDGE_MAGAZINE_REVIEW,
      "Test du magazine Edge")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_ELSPA_RATING,
      "Classification ELSPA")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_ENHANCEMENT_HW,
      "Matériel d'amélioration")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_ESRB_RATING,
      "Classification ESRB")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_FAMITSU_MAGAZINE_RATING,
      "Note du magazine Famitsu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_FRANCHISE,
      "Franchise")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_GENRE,
      "Genre")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_MD5,
      "MD5")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_NAME,
      "Nom")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_ORIGIN,
      "Origine")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_PEGI_RATING,
      "Classification PEGI")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_PUBLISHER,
      "Éditeur")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_RELEASE_MONTH,
      "Mois de sortie")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_RELEASE_YEAR,
      "Année de sortie")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_RUMBLE,
      "Support des vibrations")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_SERIAL,
      "Numéro de série")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_SHA1,
      "SHA1")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_START_CONTENT,
      "Démarrer le contenu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_TGDB_RATING,
      "Classification TGDB")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REBOOT,
      "Redémarrer")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RECORDING_CONFIG_DIRECTORY,
      "Configurations d'enregistrement vidéo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RECORDING_OUTPUT_DIRECTORY,
      "Enregistrements vidéo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RECORDING_SETTINGS,
      "Enregistrement vidéo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RECORD_CONFIG,
      "Charger une configuration d'enregistrement...")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RECORD_DRIVER,
      "Pilote d'enregistrement")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RECORD_ENABLE,
      "Activer l'enregistrement")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RECORD_PATH,
      "Sauvegarder l'enregistrement sous...")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RECORD_USE_OUTPUT_DIRECTORY,
      "Sauvegarder les enregistrement dans le dossier de sortie")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REMAP_FILE,
      "Fichier de remappage")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REMAP_FILE_LOAD,
      "Charger un fichier de remappage")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REMAP_FILE_SAVE_CORE,
      "Sauvegarder un fichier de rempappage pour le cœur")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REMAP_FILE_SAVE_GAME,
      "Sauvegarder un fichier de rempappage pour le jeu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REQUIRED,
      "Requis")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RESTART_CONTENT,
      "Redémarrer")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RESTART_RETROARCH,
      "Redémarrer RetroArch")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RESUME,
      "Reprendre")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RESUME_CONTENT,
      "Reprendre")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RETROKEYBOARD,
      "RetroKeyboard")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RETROPAD,
      "RetroPad")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RETROPAD_WITH_ANALOG,
      "RetroPad analogique")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RETRO_ACHIEVEMENTS_SETTINGS,
      "Trophées")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REWIND_ENABLE,
      "Activer le retour rapide")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REWIND_GRANULARITY,
      "Précision du retour rapide")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REWIND_SETTINGS,
      "Retour rapide")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RGUI_BROWSER_DIRECTORY,
      "Racine de la navigation")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RGUI_CONFIG_DIRECTORY,
      "Fichiers de configuration")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RGUI_SHOW_START_SCREEN,
      "Afficher l'écran de premier démarrage")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RIGHT_ANALOG,
      "Analogique droite")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RUN,
      "Lancer")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RUN_MUSIC,
      "Écouter")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAMBA_ENABLE,
      "Activer SAMBA")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVEFILE_DIRECTORY,
      "Sauvegardes de jeu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVESTATE_AUTO_INDEX,
      "Numéroter automatiquement les sauvegardes instantanées")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVESTATE_AUTO_LOAD,
      "Charger automatiquement les sauvegardes instantanées")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVESTATE_AUTO_SAVE,
      "Sauvegarde automatique")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVESTATE_DIRECTORY,
      "Sauvegarde instantanée")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVESTATE_THUMBNAIL_ENABLE,
      "Miniatures des sauvegardes instantanées")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVE_CURRENT_CONFIG,
      "Sauvegarder la configuration actuelle")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVE_CURRENT_CONFIG_OVERRIDE_CORE,
      "Sauvegarder les overrides de cœur")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVE_CURRENT_CONFIG_OVERRIDE_GAME,
      "Sauvegarder les overrides de jeu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVE_NEW_CONFIG,
      "Sauvegarder une nouvelle configuration")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVE_STATE,
      "Sauvegarder l'état")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVING_SETTINGS,
      "Sauvegardes")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SCAN_DIRECTORY,
      "Scanner un dossier")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SCAN_FILE,
      "Scanner un fichier")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SCAN_THIS_DIRECTORY,
      "<Scanner ce dossier>")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SCREENSHOT_DIRECTORY,
      "Captures d'écran")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SCREEN_RESOLUTION,
      "Résolution d'écran")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SEARCH,
      "Recherche")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SECONDS,
      "secondes")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SETTINGS,
      "Réglages")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SETTINGS_TAB,
      "Réglages")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHADER,
      "Shader")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHADER_APPLY_CHANGES,
      "Appliquer les changements")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHADER_OPTIONS,
      "Shaders")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHADER_PIPELINE_RIBBON,
      "Ruban")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHADER_PIPELINE_RIBBON_SIMPLIFIED,
      "Ruban (simplifié)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHADER_PIPELINE_SIMPLE_SNOW,
      "Neige (simplifiée)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHADER_PIPELINE_SNOW,
      "Neige")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHOW_ADVANCED_SETTINGS,
      "Afficher les réglages avancés")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHOW_HIDDEN_FILES,
      "Afficher les fichiers et les dossiers cachés")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHUTDOWN,
      "Éteindre")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SLOWMOTION_RATIO,
      "Taux de ralentissement")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SORT_SAVEFILES_ENABLE,
      "Classer les sauvegardes par dossier")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SORT_SAVESTATES_ENABLE,
      "Classer les sauvegardes instantanées par dossier")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SSH_ENABLE,
      "Activer SSH")
MSG_HASH(MENU_ENUM_LABEL_VALUE_START_CORE,
      "Démarrer le cœur")
MSG_HASH(MENU_ENUM_LABEL_VALUE_START_NET_RETROPAD,
      "Démarrer la manette réseau")
MSG_HASH(MENU_ENUM_LABEL_VALUE_START_VIDEO_PROCESSOR,
      "Démarrer le processeur vidéo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_STATE_SLOT,
      "Emplacement de sauvegarde instantanée")
MSG_HASH(MENU_ENUM_LABEL_VALUE_STATUS,
      "Statut")
MSG_HASH(MENU_ENUM_LABEL_VALUE_STDIN_CMD_ENABLE,
      "Commandes stdin")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SUPPORTED_CORES,
      "Cœurs suggérés")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SUSPEND_SCREENSAVER_ENABLE,
      "Désactiver l'économiseur d'écran")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_BGM_ENABLE,
      "Musique du système activée")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_DIRECTORY,
      "Système/BIOS")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFORMATION,
      "Informations du système")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_7ZIP_SUPPORT,
      "Support de 7zip")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_ALSA_SUPPORT,
      "Support d'ALSA")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_BUILD_DATE,
      "Date de build")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_CG_SUPPORT,
      "Support de CG")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_COCOA_SUPPORT,
      "Support de Cocoa")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_COMMAND_IFACE_SUPPORT,
      "Support de l'interface de commandes")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_CORETEXT_SUPPORT,
      "Support de CoreText")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_CPU_FEATURES,
      "Fonctionnalités du CPU")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_DISPLAY_METRIC_DPI,
      "DPI de l'affichage")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_DISPLAY_METRIC_MM_HEIGHT,
      "Hauteur de l'affichage (mm)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_DISPLAY_METRIC_MM_WIDTH,
      "Largeur de l'affichage (mm)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_DSOUND_SUPPORT,
      "Support de DirectSound")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_WASAPI_SUPPORT,
      "Support de WASAPI")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_DYLIB_SUPPORT,
      "Support des bibliothèques dynamiques")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_DYNAMIC_SUPPORT,
      "Support du chargement dynamiques des bibliothèques")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_EGL_SUPPORT,
      "Support d'EGL")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_FBO_SUPPORT,
      "Support d'OpenGL/Direct3D render-to-texture (shaders multi-passages)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_FFMPEG_SUPPORT,
      "Support de FFmpeg")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_FREETYPE_SUPPORT,
      "Support de FreeType")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_FRONTEND_IDENTIFIER,
      "Identifiant frontend")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_FRONTEND_NAME,
      "Nom du frontend")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_FRONTEND_OS,
      "OS du frontend")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_GIT_VERSION,
      "Version Git")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_GLSL_SUPPORT,
      "Support de GLSL")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_HLSL_SUPPORT,
      "Support de HLSL")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_JACK_SUPPORT,
      "Support de JACK")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_KMS_SUPPORT,
      "Support de KMS/EGL")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_LAKKA_VERSION,
      "Version de Lakka")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_LIBRETRODB_SUPPORT,
      "Support de LibretroDB")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_LIBUSB_SUPPORT,
      "Support de Libusb")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_LIBXML2_SUPPORT,
      "Support du parser XML libxml2")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_NETPLAY_SUPPORT,
      "Support du jeu en réseau (peer-to-peer)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_NETWORK_COMMAND_IFACE_SUPPORT,
      "Support des commandes réseau")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_NETWORK_REMOTE_SUPPORT,
      "Support de la manette réseau")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_OPENAL_SUPPORT,
      "Support d'OpenAL")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_OPENGLES_SUPPORT,
      "Support d'OpenGL ES")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_OPENGL_SUPPORT,
      "Support d'OpenGL")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_OPENSL_SUPPORT,
      "Support d'OpenSL")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_OPENVG_SUPPORT,
      "Support d'OpenVG")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_OSS_SUPPORT,
      "Support d'OSS")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_OVERLAY_SUPPORT,
      "Support des overlays")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_POWER_SOURCE,
      "Alimentation")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_POWER_SOURCE_CHARGED,
      "Chargée")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_POWER_SOURCE_CHARGING,
      "En chargement")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_POWER_SOURCE_DISCHARGING,
      "Déchargé")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_POWER_SOURCE_NO_SOURCE,
      "Non alimenté")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_PULSEAUDIO_SUPPORT,
      "Support de PulseAudio")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_PYTHON_SUPPORT,
      "Support de Python (scripting des shaders)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_RBMP_SUPPORT,
      "Support de BMP (RBMP)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_RETRORATING_LEVEL,
      "Niveau RetroRating")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_RJPEG_SUPPORT,
      "Support de JPEG (RJPEG)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_ROARAUDIO_SUPPORT,
      "Support de RoarAudio")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_RPNG_SUPPORT,
      "Support de PNG (RPNG)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_RSOUND_SUPPORT,
      "Support de RSound")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_RTGA_SUPPORT,
      "Support de TGA (RTGA)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_SDL2_SUPPORT,
      "Support de SDL2")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_SDL_IMAGE_SUPPORT,
      "Support de SDL image")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_SDL_SUPPORT,
      "Support de SDL1.2")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_SLANG_SUPPORT,
      "Support de Slang")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_THREADING_SUPPORT,
      "Support du threading")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_UDEV_SUPPORT,
      "Support de udev")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_V4L2_SUPPORT,
      "Support de Video4Linux2")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_VIDEO_CONTEXT_DRIVER,
      "Pilote du contexte vidéo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_VULKAN_SUPPORT,
      "Support de Vulkan")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_WAYLAND_SUPPORT,
      "Support de Wayland")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_X11_SUPPORT,
      "Support de X11")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_XAUDIO2_SUPPORT,
      "Support de XAudio2")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_XVIDEO_SUPPORT,
      "Support de XVideo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_ZLIB_SUPPORT,
      "Support de Zlib")
MSG_HASH(MENU_ENUM_LABEL_VALUE_TAKE_SCREENSHOT,
      "Capturer l'écran")
MSG_HASH(MENU_ENUM_LABEL_VALUE_THREADED_DATA_RUNLOOP_ENABLE,
      "Tâches threadées")
MSG_HASH(MENU_ENUM_LABEL_VALUE_THUMBNAILS,
      "Vignettes")
MSG_HASH(MENU_ENUM_LABEL_VALUE_THUMBNAILS_DIRECTORY,
      "Vignettes")
MSG_HASH(MENU_ENUM_LABEL_VALUE_THUMBNAILS_UPDATER_LIST,
      "Mises à jour des vignettes")
MSG_HASH(MENU_ENUM_LABEL_VALUE_THUMBNAIL_MODE_BOXARTS,
      "Jaquettes")
MSG_HASH(MENU_ENUM_LABEL_VALUE_THUMBNAIL_MODE_SCREENSHOTS,
      "Captures d'écran")
MSG_HASH(MENU_ENUM_LABEL_VALUE_THUMBNAIL_MODE_TITLE_SCREENS,
      "Écrans titres")
MSG_HASH(MENU_ENUM_LABEL_VALUE_TIMEDATE_ENABLE,
      "Afficher la date et l'heure")
MSG_HASH(MENU_ENUM_LABEL_VALUE_TITLE_COLOR,
      "Couleur du titre du menu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_TRUE,
      "Vrai")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UI_COMPANION_ENABLE,
      "Activer le compagnon d'interface")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UI_COMPANION_START_ON_BOOT,
      "Lancer le compagnon d'interface au démarrage")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UI_MENUBAR_ENABLE,
      "Barre de menu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UNABLE_TO_READ_COMPRESSED_FILE,
      "Impossible de lire l'archive.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UNDO_LOAD_STATE,
      "Annuler le dernier chargement de sauvegarde instantanée")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UNDO_SAVE_STATE,
      "Annuler la dernière sauvegarde instantanée")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UNKNOWN,
      "Inconnu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATER_SETTINGS,
      "Mises à jour")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_ASSETS,
      "Mettre à jour les assets")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_AUTOCONFIG_PROFILES,
      "Mettre à jour les profils d'autoconfiguration")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_CG_SHADERS,
      "Mettre à jour les shaders CG")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_CHEATS,
      "Mettre à jour les codes de triche")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_CORE_INFO_FILES,
      "Mettre à jour les informations des cœurs")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_DATABASES,
      "Mettre à jour les bases de données")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_GLSL_SHADERS,
      "Mettre à jour les shaders GLSL")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_LAKKA,
      "Mises à jour de Lakka")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_OVERLAYS,
      "Mettre à jour les overlays")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_SLANG_SHADERS,
      "Mettre à jour les shaders Slang")
MSG_HASH(MENU_ENUM_LABEL_VALUE_USER,
      "Utilisateur")
MSG_HASH(MENU_ENUM_LABEL_VALUE_USER_INTERFACE_SETTINGS,
      "Interface graphique")
MSG_HASH(MENU_ENUM_LABEL_VALUE_USER_LANGUAGE,
      "Langue")
MSG_HASH(MENU_ENUM_LABEL_VALUE_USER_SETTINGS,
      "Utilisateur")
MSG_HASH(MENU_ENUM_LABEL_VALUE_USE_BUILTIN_IMAGE_VIEWER,
      "Utiliser le lecteur d'image embarqué")
MSG_HASH(MENU_ENUM_LABEL_VALUE_USE_BUILTIN_PLAYER,
      "Utiliser le lecteur média embarqué")
MSG_HASH(MENU_ENUM_LABEL_VALUE_USE_THIS_DIRECTORY,
      "<Utiliser ce dossier>")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_ALLOW_ROTATE,
      "Autoriser la rotation")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_ASPECT_RATIO,
      "Rapport d'aspect personnalisé")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_ASPECT_RATIO_AUTO,
      "Rapport d'aspect automatique")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_ASPECT_RATIO_INDEX,
      "Rapport d'aspect")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_BLACK_FRAME_INSERTION,
      "Insertion d'images noires")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_CROP_OVERSCAN,
      "Tronquer l'overscan (Reload)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_DISABLE_COMPOSITION,
      "Désactiver le compositeur de bureau")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_DRIVER,
      "Pilote vidéo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FILTER,
      "Filtre vidéo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FILTER_DIR,
      "Filtres vidéo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FILTER_FLICKER,
      "Filtre anti-scintillement")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FONT_ENABLE,
      "Afficher les notifications")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FONT_PATH,
      "Police des notifications")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FONT_SIZE,
      "Taille du texte des notifications")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FORCE_ASPECT,
      "Forcer le rapport d'aspect")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FORCE_SRGB_DISABLE,
      "Désactiver sRGB FBO")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FRAME_DELAY,
      "Retarder les images")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FULLSCREEN,
      "Plein écran")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_GAMMA,
      "Gamma")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_GPU_RECORD,
      "Captures vidéo via le GPU")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_GPU_SCREENSHOT,
      "Captures d'écran GPU")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_HARD_SYNC,
      "Synchroniser le GPU au CPU")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_HARD_SYNC_FRAMES,
      "Trames de synchro GPU")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_MAX_SWAPCHAIN_IMAGES,
      "Nombre max de tampons d'image")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_MESSAGE_POS_X,
      "Position sur X")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_MESSAGE_POS_Y,
      "Position sur Y")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_MONITOR_INDEX,
      "Écran")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_POST_FILTER_RECORD,
      "Activer les filtres de traitement")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_REFRESH_RATE,
      "Fréquence de rafraîchissement verticale")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_REFRESH_RATE_AUTO,
      "Fréquence estimée de l'écran")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_REFRESH_RATE_POLLED,
      "Set Display-Reported Refresh Rate")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_ROTATION,
      "Rotation")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SCALE,
      "Zoom (en fenêtre)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SCALE_INTEGER,
      "Zoom entier")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SETTINGS,
      "Vidéo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SHADER_DIR,
      "Shaders")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SHADER_NUM_PASSES,
      "Nombre de passages")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SHADER_PARAMETERS,
      "Prévisualiser les paramètres")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SHADER_PRESET,
      "Charger un pré-réglage de shader")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SHADER_PRESET_SAVE_AS,
      "Enregistrer le pré-réglage sous")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SHADER_PRESET_SAVE_CORE,
      "Sauvegarder le pré-réglage pour ce core")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SHADER_PRESET_SAVE_GAME,
      "Sauvegarder le pré-réglage pour ce jeu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SHARED_CONTEXT,
      "Contexte matériel partagé")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SMOOTH,
      "Filtre bilinéaire (HW)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SOFT_FILTER,
      "Filtre (SW)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SWAP_INTERVAL,
      "Intervalle de synchronisation verticale")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_TAB,
      "Vidéo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_THREADED,
      "Threader l'affichage")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_VFILTER,
      "Deflicker")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_VIEWPORT_CUSTOM_HEIGHT,
      "Hauteur de fenêtre personnalisée")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_VIEWPORT_CUSTOM_WIDTH,
      "Largeur de fenêtre personnalisée")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_VIEWPORT_CUSTOM_X,
      "Position horizontale personnalisée")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_VIEWPORT_CUSTOM_Y,
      "Position verticale personnalisée")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_VI_WIDTH,
      "Set VI Screen Width")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_VSYNC,
      "Synchronisation verticale")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_WINDOWED_FULLSCREEN,
      "Mode plein écran fenêtré")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_WINDOW_WIDTH,
      "Largeur de fenêtre")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_WINDOW_HEIGHT,
      "Hauteur de fenêtre")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FULLSCREEN_X,
      "Largeur plein écran")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FULLSCREEN_Y,
      "Hauteur plein écran")
MSG_HASH(MENU_ENUM_LABEL_VALUE_WIFI_DRIVER,
      "Pilote Wi-Fi")
MSG_HASH(MENU_ENUM_LABEL_VALUE_WIFI_SETTINGS,
      "Wi-Fi")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ALPHA_FACTOR,
      "Transparence du fond")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_FONT_COLOR_RED,
      "Menu Font Red Color")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_FONT_COLOR_GREEN,
      "Menu Font Green Color")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_FONT_COLOR_BLUE,
      "Menu Font Blue Color")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_FONT,
      "Police du menu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_CUSTOM,
      "Perso")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_FLATUI,
      "FlatUI")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_MONOCHROME,
      "Monochrome")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_MONOCHROME_INVERTED,
      "Monochrome Inverted")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_SYSTEMATIC,
      "Systematic")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_NEOACTIVE,
      "NeoActive")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_PIXEL,
      "Pixel")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_RETROACTIVE,
      "RetroActive")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_RETROSYSTEM,
      "Retrosystem")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_DOTART,
      "Dot-Art")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME,
      "Palette du menu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_APPLE_GREEN,
      "Vert Pomme")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_DARK,
      "Sombre")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_DARK_PURPLE,
      "Violet Foncé")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_ELECTRIC_BLUE,
      "Bleu Électrique")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_GOLDEN,
      "Doré")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_LEGACY_RED,
      "Rouge (Legacy)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_MIDNIGHT_BLUE,
      "Bleu Nuit")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_PLAIN,
      "Uni")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_UNDERSEA,
      "Fonds marins")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_VOLCANIC_RED,
      "Rouge Volcanique")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_RIBBON_ENABLE,
      "Fond d'écran animé")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_SCALE_FACTOR,
      "Taille du texte du menu")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_SHADOWS_ENABLE,
      "Ombres pour les icônes")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_HISTORY,
      "Afficher l'onglet Historique")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_IMAGES,
      "Afficher l'onglet Images")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_MUSIC,
      "Afficher l'onglet Musique")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_SETTINGS,
      "Afficher l'onglet Paramètres")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_VIDEO,
      "Afficher l'onglet Vidéo")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_LAYOUT,
      "Menu Layout")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_THEME,
      "Thème XMB")
MSG_HASH(MENU_ENUM_LABEL_VALUE_YES,
      "Oui")
MSG_HASH(MENU_ENUM_LABEL_VIDEO_SHADER_PRESET_TWO,
      "Pré-réglage de shader")
MSG_HASH(MENU_ENUM_SUBLABEL_CHEEVOS_ENABLE,
      "Activer/désactiver les trophées. Pour plus d'information, visiter http://retroachievements.org")
MSG_HASH(MENU_ENUM_SUBLABEL_CHEEVOS_TEST_UNOFFICIAL,
      "Activer/désactiver les trophées non-officiels et/ou les fonctionnalités en beta à des fins de test.")
MSG_HASH(MENU_ENUM_SUBLABEL_CHEEVOS_HARDCORE_MODE_ENABLE,
      "En mode hardcore, les sauvegardes instantanées, la triche, le retour rapide, la pause et le ralenti seront désactivés.")
MSG_HASH(MENU_ENUM_SUBLABEL_DRIVER_SETTINGS,
      "Modifier les pilotes pour ce système.")
MSG_HASH(MENU_ENUM_SUBLABEL_RETRO_ACHIEVEMENTS_SETTINGS,
      "Modifier les paramètres des trophées.")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_SETTINGS,
      "Modifier les paramètres des cœurs.")
MSG_HASH(MENU_ENUM_SUBLABEL_RECORDING_SETTINGS,
      "Modifier les paramètres d'enregistrement.")
MSG_HASH(MENU_ENUM_SUBLABEL_ONSCREEN_DISPLAY_SETTINGS,
      "Modifier les paramètres d'overlay à l'écran, d'overlay clavier et de notifications.")
MSG_HASH(MENU_ENUM_SUBLABEL_FRAME_THROTTLE_SETTINGS,
      "Modifier les paramètres de retour rapide, d'avance rapide et de ralenti.")
MSG_HASH(MENU_ENUM_SUBLABEL_SAVING_SETTINGS,
      "Modifier les paramètres de sauvegarde.")
MSG_HASH(MENU_ENUM_SUBLABEL_LOGGING_SETTINGS,
      "Modifier les paramètres de journalisation.")
MSG_HASH(MENU_ENUM_SUBLABEL_USER_INTERFACE_SETTINGS,
      "Modifier les paramètres de l'interface utilisateur.")
MSG_HASH(MENU_ENUM_SUBLABEL_USER_SETTINGS,
      "Modifier les comptes, pseudos, et langues.")
MSG_HASH(MENU_ENUM_SUBLABEL_PRIVACY_SETTINGS,
      "Modifier les paramètres de vie privée.")
MSG_HASH(MENU_ENUM_SUBLABEL_DIRECTORY_SETTINGS,
      "Modifier les répertoires par défaut pour ce système.")
MSG_HASH(MENU_ENUM_SUBLABEL_PLAYLIST_SETTINGS,
      "Modifier les paramètres des playlists.")
MSG_HASH(MENU_ENUM_SUBLABEL_NETWORK_SETTINGS,
      "Configurer les paramètres de serveurs et de réseau.")
MSG_HASH(MENU_ENUM_SUBLABEL_ADD_CONTENT_LIST,
      "Scanner les contenus et les ajouter à la base de données.")
MSG_HASH(MENU_ENUM_SUBLABEL_AUDIO_SETTINGS,
      "Ajuster les paramètres de sortie audio.")
MSG_HASH(MENU_ENUM_SUBLABEL_BLUETOOTH_ENABLE,
      "Activer ou désactiver le Bluetooth.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONFIG_SAVE_ON_EXIT,
      "Sauvegarder les modifications dans le fichier de configuration en quittant.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONFIGURATION_SETTINGS,
      "Modifier les paramètres par défaut pour les fichiers de configuration.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONFIGURATIONS_LIST,
      "Créer et gérer les fichiers de configuration.")
MSG_HASH(MENU_ENUM_SUBLABEL_CPU_CORES,
      "Nombre de cœurs du CPU.")
MSG_HASH(MENU_ENUM_SUBLABEL_FPS_SHOW,
      "Affiche le nombre d'images par seconde à l'écran.")
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_HOTKEY_BINDS,
      "Configurer les paramètres des raccourcis clavier.")
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_MENU_ENUM_TOGGLE_GAMEPAD_COMBO,
      "Combinaison de boutons manette pour afficher le menu.")
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_SETTINGS,
      "Ajuster les paramètres des manettes, du clavier et de la souris.")
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_USER_BINDS,
      "Configurer les contrôles pour cet utilisateur.")
MSG_HASH(MENU_ENUM_SUBLABEL_LOG_VERBOSITY,
      "Activer ou désactiver la journalisation dans le terminal.")
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY,
      "Rejoindre ou héberger une session réseau.")
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY_LAN_SCAN_SETTINGS,
      "Trouver et rejoindre une session réseau local.")
MSG_HASH(MENU_ENUM_SUBLABEL_INFORMATION_LIST_LIST,
      "Afficher les informations de cœurs, de réseau et du système.")
MSG_HASH(MENU_ENUM_SUBLABEL_ONLINE_UPDATER,
      "Télécharger des add-ons, des composants et du contenu pour RetroArch.")
MSG_HASH(MENU_ENUM_SUBLABEL_SAMBA_ENABLE,
      "Activer ou désactiver le partage réseau des dossiers.")
MSG_HASH(MENU_ENUM_SUBLABEL_SERVICES_SETTINGS,
      "Gérer les services système.")
MSG_HASH(MENU_ENUM_SUBLABEL_SHOW_HIDDEN_FILES,
      "Afficher les dossiers et fichiers cachés dans l'explorateur.")
MSG_HASH(MENU_ENUM_SUBLABEL_SSH_ENABLE,
      "Activer ou désactiver l'accès distant via la ligne de commande.")
MSG_HASH(MENU_ENUM_SUBLABEL_SUSPEND_SCREENSAVER_ENABLE,
      "Empêche l'activation de l'économiseur d'écran.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_WINDOW_SCALE,
      "Configure la taille de la fenêtre en fonction du viewport du cœur. Sinon, vous pouvez définir une taille fixe pour la fenêtre ci dessous.")
MSG_HASH(MENU_ENUM_SUBLABEL_USER_LANGUAGE,
      "Définit la langue de l'interface.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_BLACK_FRAME_INSERTION,
      "Insère une image noire entre chaque image. Utile pour les utilisateurs de moniteurs 120 Hz qui veulent pouvoir jouer à du contenu à 60 Hz sans ghosting.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_FRAME_DELAY,
      "Réduit la latence au risque d'augmenter les saccades. Ajoute un délai après la synchronisation verticale (en ms).")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_HARD_SYNC_FRAMES,
      "Définit le nombre d'images que le CPU peut calculer avant le GPU lorsque la synchronisation GPU est active.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_MAX_SWAPCHAIN_IMAGES,
      "Indique au pilote graphique d'utiliser un mode de tampon spécifique.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_MONITOR_INDEX,
      "Sélectionne l'écran à utiliser.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_REFRESH_RATE_AUTO,
      "Taux de rafraîchissement estimé de l'écran en Hz.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_REFRESH_RATE_POLLED,
      "The refresh rate as reported by the display driver.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SETTINGS,
      "Ajuster les paramètres de sortie vidéo.")
MSG_HASH(MENU_ENUM_SUBLABEL_WIFI_SETTINGS,
      "Scanner les réseaux Wi-Fi et établir une connexion.")
MSG_HASH(MENU_ENUM_SUBLABEL_HELP_LIST,
      "Mieux comprendre comment ça marche.")
MSG_HASH(MSG_APPENDED_DISK,
      "Disque ajouté")
MSG_HASH(MSG_APPLICATION_DIR,
      "Dossier de l'application.")
MSG_HASH(MSG_APPLYING_CHEAT,
      "Appliquer les changements de triche.")
MSG_HASH(MSG_APPLYING_SHADER,
      "Application du shader")
MSG_HASH(MSG_AUDIO_MUTED,
      "Son coupé.")
MSG_HASH(MSG_AUDIO_UNMUTED,
      "Remise du son.")
MSG_HASH(MSG_AUTOCONFIG_FILE_ERROR_SAVING,
      "Erreur lors de l'enregistrement du fichier d'autoconfiguration.")
MSG_HASH(MSG_AUTOCONFIG_FILE_SAVED_SUCCESSFULLY,
      "Enregistrement réussi du fichier d'autoconfiguration.")
MSG_HASH(MSG_AUTOSAVE_FAILED,
      "Impossible d'activer l'enregistrement automatique.")
MSG_HASH(MSG_AUTO_SAVE_STATE_TO,
      "Sauvegarde instantanée automatique vers")
MSG_HASH(MSG_BLOCKING_SRAM_OVERWRITE,
      "Bloque l'écrasement de la SRAM")
MSG_HASH(MSG_BRINGING_UP_COMMAND_INTERFACE_ON_PORT,
      "Amener l'interface de commande sur le port")
MSG_HASH(MSG_BYTES,
      "octets")
MSG_HASH(MSG_CANNOT_INFER_NEW_CONFIG_PATH,
      "Impossible de déduire le nouveau chemin de configuration. Utilisation de l'heure actuelle.")
MSG_HASH(MSG_CHEEVOS_HARDCORE_MODE_ENABLE,
      "Mode hardcore activé, La sauvegarde instantanée et le retour rapide sont désactivés.")
MSG_HASH(MSG_COMPARING_WITH_KNOWN_MAGIC_NUMBERS,
      "Comparaison avec les nombres magiques connus...")
MSG_HASH(MSG_COMPILED_AGAINST_API,
      "Compilé depuis l'API")
MSG_HASH(MSG_CONFIG_DIRECTORY_NOT_SET,
      "Répertoire de configuration non défini. Impossible de sauvegarder le nouveau fichier.")
MSG_HASH(MSG_CONNECTED_TO,
      "Connecté à")
MSG_HASH(MSG_CONTENT_CRC32S_DIFFER,
      "Le contenu du CRC32 est différent. Impossible d'utiliser des jeux non-identiques.")
MSG_HASH(MSG_CONTENT_LOADING_SKIPPED_IMPLEMENTATION_WILL_DO_IT,
      "Chargement du contenu ignoré. L'implémentation va le charger d'elle-même.")
MSG_HASH(MSG_CORE_DOES_NOT_SUPPORT_SAVESTATES,
      "Le cœur ne supporte pas les sauvegardes instantanées.")
MSG_HASH(MSG_CORE_OPTIONS_FILE_CREATED_SUCCESSFULLY,
      "Le fichier d'options du cœur a été créé.")
MSG_HASH(MSG_COULD_NOT_FIND_ANY_NEXT_DRIVER,
      "Impossible de trouver d'autre pilote.")
MSG_HASH(MSG_COULD_NOT_FIND_COMPATIBLE_SYSTEM,
      "Impossible de trouver un système compatible.")
MSG_HASH(MSG_COULD_NOT_FIND_VALID_DATA_TRACK,
      "Impossible de trouver de données valides.")
MSG_HASH(MSG_COULD_NOT_OPEN_DATA_TRACK,
      "could not open data track")
MSG_HASH(MSG_COULD_NOT_READ_CONTENT_FILE,
      "Impossible de lire le contenu du fichier")
MSG_HASH(MSG_COULD_NOT_READ_MOVIE_HEADER,
      "Impossible de lire l'entête du film.")
MSG_HASH(MSG_COULD_NOT_READ_STATE_FROM_MOVIE,
      "Impossible de lire l'état du film.")
MSG_HASH(MSG_CRC32_CHECKSUM_MISMATCH,
      "Le checksum du CRC32 est différent entre le contenu du fichier et celui des données sauvegardées dans l'entête du fichier de replay. le replay a de grandes chances de se désynchroniser à la lecture.")
MSG_HASH(MSG_CUSTOM_TIMING_GIVEN,
      "Temps personnalisé attribué")
MSG_HASH(MSG_DECOMPRESSION_ALREADY_IN_PROGRESS,
      "Décompression en cours.")
MSG_HASH(MSG_DECOMPRESSION_FAILED,
      "Échec de la décompression.")
MSG_HASH(MSG_DETECTED_VIEWPORT_OF,
      "Détection du visuel")
MSG_HASH(MSG_DID_NOT_FIND_A_VALID_CONTENT_PATCH,
      "Impossible de trouver un patch de contenu valide.")
MSG_HASH(MSG_DISCONNECT_DEVICE_FROM_A_VALID_PORT,
      "Déconnexion du périphérique depuis un port valide.")
MSG_HASH(MSG_DISK_CLOSED,
      "Fermé")
MSG_HASH(MSG_DISK_EJECTED,
      "Éjecté")
MSG_HASH(MSG_DOWNLOADING,
      "Téléchargement")
MSG_HASH(MSG_DOWNLOAD_FAILED,
      "Échec du téléchargement")
MSG_HASH(MSG_ERROR,
      "Erreur")
MSG_HASH(MSG_ERROR_LIBRETRO_CORE_REQUIRES_CONTENT,
      "Le cœur nécessite un contenu, or aucun n'a été fourni.")
MSG_HASH(MSG_ERROR_LIBRETRO_CORE_REQUIRES_SPECIAL_CONTENT,
      "Le cœur nécessite un contenu spécial, or aucun n'a été fourni.")
MSG_HASH(MSG_ERROR_PARSING_ARGUMENTS,
      "Erreur lors de l'analyse des arguments.")
MSG_HASH(MSG_ERROR_SAVING_CORE_OPTIONS_FILE,
      "Erreur lors de l'enregistrement du fichier d'option du cœur.")
MSG_HASH(MSG_ERROR_SAVING_REMAP_FILE,
      "Erreur lors de l'enregistrement du fichier de remap.")
MSG_HASH(MSG_ERROR_SAVING_SHADER_PRESET,
      "Erreur lors de l'enregistrement du preset de shader.")
MSG_HASH(MSG_EXTERNAL_APPLICATION_DIR,
      "Répertoire d'application externe.")
MSG_HASH(MSG_EXTRACTING,
      "Extraction")
MSG_HASH(MSG_EXTRACTING_FILE,
      "Fichier en cours d'extraction")
MSG_HASH(MSG_FAILED_SAVING_CONFIG_TO,
      "Erreur lors de la sauvegarde de la configuration vers")
MSG_HASH(MSG_FAILED_TO,
      "Échec de")
MSG_HASH(MSG_FAILED_TO_ACCEPT_INCOMING_SPECTATOR,
      "Échec de l'accueil du spectateur entrant.")
MSG_HASH(MSG_FAILED_TO_ALLOCATE_MEMORY_FOR_PATCHED_CONTENT,
      "Échec d'allocation mémoire pour le contenu patché...")
MSG_HASH(MSG_FAILED_TO_APPLY_SHADER,
      "Impossible d'appliquer le shader.")
MSG_HASH(MSG_FAILED_TO_BIND_SOCKET,
      "Échec d'attribution du socket.")
MSG_HASH(MSG_FAILED_TO_CREATE_THE_DIRECTORY,
      "Échec de création du répertoire.")
MSG_HASH(MSG_FAILED_TO_EXTRACT_CONTENT_FROM_COMPRESSED_FILE,
      "Échec de l'extraction du contenu depuis le fichier compressé.")
MSG_HASH(MSG_FAILED_TO_GET_NICKNAME_FROM_CLIENT,
      "Échec d'obtention du pseudo depuis le client.")
MSG_HASH(MSG_FAILED_TO_LOAD,
      "Échec du chargement")
MSG_HASH(MSG_FAILED_TO_LOAD_CONTENT,
      "Échec du chargement du fichier")
MSG_HASH(MSG_FAILED_TO_LOAD_MOVIE_FILE,
      "Échec du chargement du fichier vidéo")
MSG_HASH(MSG_FAILED_TO_LOAD_OVERLAY,
      "Impossible de charger l'overlay.")
MSG_HASH(MSG_FAILED_TO_LOAD_STATE,
      "Impossible de charger la sauvegarde instantanée à partir de")
MSG_HASH(MSG_FAILED_TO_OPEN_LIBRETRO_CORE,
      "Échec de l'ouverture du cœur Libretro")
MSG_HASH(MSG_FAILED_TO_PATCH,
      "Échec du patch")
MSG_HASH(MSG_FAILED_TO_RECEIVE_HEADER_FROM_CLIENT,
      "Échec de l'obtention de l'entête depuis le client.")
MSG_HASH(MSG_FAILED_TO_RECEIVE_NICKNAME,
      "Échec de l'obtention du pseudo.")
MSG_HASH(MSG_FAILED_TO_RECEIVE_NICKNAME_FROM_HOST,
      "Échec de l'obtention du pseudo depuis l'hôte.")
MSG_HASH(MSG_FAILED_TO_RECEIVE_NICKNAME_SIZE_FROM_HOST,
      "Échec de l'obtention de la taille du pseudo depuis l'hôte.")
MSG_HASH(MSG_FAILED_TO_RECEIVE_SRAM_DATA_FROM_HOST,
      "Échec de l'obtention des données SRAM depuis l'hôte.")
MSG_HASH(MSG_FAILED_TO_REMOVE_DISK_FROM_TRAY,
      "Impossible d'éjecter le disque du lecteur.")
MSG_HASH(MSG_FAILED_TO_REMOVE_TEMPORARY_FILE,
      "Impossible de supprimer le fichier temporaire")
MSG_HASH(MSG_FAILED_TO_SAVE_SRAM,
      "Impossible de sauvegarder la SRAM")
MSG_HASH(MSG_FAILED_TO_SAVE_STATE_TO,
      "Impossible d'enregistrer la sauvegarde instantanée vers")
MSG_HASH(MSG_FAILED_TO_SEND_NICKNAME,
      "Échec de l'envoi du pseudo.")
MSG_HASH(MSG_FAILED_TO_SEND_NICKNAME_SIZE,
      "Échec de l'envoi de la taille du pseudo.")
MSG_HASH(MSG_FAILED_TO_SEND_NICKNAME_TO_CLIENT,
      "Échec de l'envoi du pseudo vers le client.")
MSG_HASH(MSG_FAILED_TO_SEND_NICKNAME_TO_HOST,
      "Échec de l'envoi du pseudo vers l'hôte.")
MSG_HASH(MSG_FAILED_TO_SEND_SRAM_DATA_TO_CLIENT,
      "Échec de l'envoi des données SRAM au client.")
MSG_HASH(MSG_FAILED_TO_START_AUDIO_DRIVER,
      "Échec du démarrage du pilote audio. Pas de son.")
MSG_HASH(MSG_FAILED_TO_START_MOVIE_RECORD,
      "Impossible de démarrer l'enregistrement vidéo.")
MSG_HASH(MSG_FAILED_TO_START_RECORDING,
      "Échec de l'activation de l'enregistrement.")
MSG_HASH(MSG_FAILED_TO_TAKE_SCREENSHOT,
      "Échec de la capture d'écran.")
MSG_HASH(MSG_FAILED_TO_UNDO_LOAD_STATE,
      "Aucun savestate de retour arrière trouvé")
MSG_HASH(MSG_FAILED_TO_UNDO_SAVE_STATE,
      "Impossible de sauvegarder les informations de savestate de retour arrière")
MSG_HASH(MSG_FAILED_TO_UNMUTE_AUDIO,
      "Impossible de remettre le son.")
MSG_HASH(MSG_FATAL_ERROR_RECEIVED_IN,
      "Erreur fatale dans")
MSG_HASH(MSG_FILE_NOT_FOUND,
      "Fichier non trouvé.")
MSG_HASH(MSG_FOUND_AUTO_SAVESTATE_IN,
      "Sauvegarde instantanée automatique trouvée dans")
MSG_HASH(MSG_FOUND_DISK_LABEL,
      "Étiquette du disque trouvée")
MSG_HASH(MSG_FOUND_FIRST_DATA_TRACK_ON_FILE,
      "Première piste de données trouvée sur le fichier")
MSG_HASH(MSG_FOUND_LAST_STATE_SLOT,
      "Dernier emplacement d'état trouvé")
MSG_HASH(MSG_FOUND_SHADER,
      "Shader trouvé")
MSG_HASH(MSG_FRAMES,
      "Images")
MSG_HASH(MSG_GAME_SPECIFIC_CORE_OPTIONS_FOUND_AT,
      "Options par jeu : options de cœur pour le jeu trouvées dans")
MSG_HASH(MSG_GOT_INVALID_DISK_INDEX,
      "Index du disque invalide.")
MSG_HASH(MSG_GRAB_MOUSE_STATE,
      "Capture la souris")
MSG_HASH(MSG_GAME_FOCUS_ON,
      "Focus sur le jeu : ON")
MSG_HASH(MSG_GAME_FOCUS_OFF,
      "Focus sur le jeu : OFF")
MSG_HASH(MSG_HW_RENDERED_MUST_USE_POSTSHADED_RECORDING,
      "Le cœur utilise le rendu matériel. Obligation d'utiliser également l'enregistrement post-shaded.")
MSG_HASH(MSG_INFLATED_CHECKSUM_DID_NOT_MATCH_CRC32,
      "La somme de contrôle gonflée ne correspond pas au CRC32.")
MSG_HASH(MSG_INPUT_CHEAT,
      "Saisir le code de triche")
MSG_HASH(MSG_INPUT_CHEAT_FILENAME,
      "Nom du fichier de triche")
MSG_HASH(MSG_INPUT_PRESET_FILENAME,
      "Nom du fichier de pré-réglage")
MSG_HASH(MSG_INPUT_RENAME_ENTRY,
      "Rename Title")
MSG_HASH(MSG_INTERFACE,
      "Interface")
MSG_HASH(MSG_INTERNAL_STORAGE,
      "Stockage interne")
MSG_HASH(MSG_REMOVABLE_STORAGE,
      "Stockage amovible")
MSG_HASH(MSG_INVALID_NICKNAME_SIZE,
      "Taille du pseudo non-valide.")
MSG_HASH(MSG_IN_BYTES,
      "en octets")
MSG_HASH(MSG_IN_GIGABYTES,
      "en gigaoctets")
MSG_HASH(MSG_IN_MEGABYTES,
      "en mégaoctets")
MSG_HASH(MSG_LIBRETRO_ABI_BREAK,
      "est compilé avec une version différente de la bibliothèque libretro actuelle.")
MSG_HASH(MSG_LIBRETRO_FRONTEND,
      "Frontend pour libretro")
MSG_HASH(MSG_LOADED_STATE_FROM_SLOT,
      "Chargement de la sauvegarde instantanée à partir de l'emplacement #%d.")
MSG_HASH(MSG_LOADED_STATE_FROM_SLOT_AUTO,
      "Chargement de la sauvegarde instantanée à partir de l'emplacement #-1 (auto).")
MSG_HASH(MSG_LOADING,
      "Chargement")
MSG_HASH(MSG_FIRMWARE,
      "Un ou plusieurs firmware sont manquants")
MSG_HASH(MSG_LOADING_CONTENT_FILE,
      "Chargement du contenu")
MSG_HASH(MSG_LOADING_HISTORY_FILE,
      "Chargement du fichier d'historique")
MSG_HASH(MSG_LOADING_STATE,
      "Chargement de la sauvegarde instantanée")
MSG_HASH(MSG_MEMORY,
      "Mémoire")
MSG_HASH(MSG_MOVIE_FILE_IS_NOT_A_VALID_BSV1_FILE,
      "Le fichier vidéo n'est pas un fichier BSV1 valide.")
MSG_HASH(MSG_MOVIE_FORMAT_DIFFERENT_SERIALIZER_VERSION,
      "Le format du film semble avoir une version de sérialisation différent. Échec très probable.")
MSG_HASH(MSG_MOVIE_PLAYBACK_ENDED,
      "Fin de la lecture vidéo")
MSG_HASH(MSG_MOVIE_RECORD_STOPPED,
      "Arrêt de l'enregistrement vidéo.")
MSG_HASH(MSG_NETPLAY_FAILED,
      "Échec de l'initialisation du jeu en réseau")
MSG_HASH(MSG_NO_CONTENT_STARTING_DUMMY_CORE,
      "Aucun contenu, chargement d'un cœur factice.")
MSG_HASH(MSG_NO_SAVE_STATE_HAS_BEEN_OVERWRITTEN_YET,
      "Aucun état de sauvegarde n'a été écrasé pour l'instant.")
MSG_HASH(MSG_NO_STATE_HAS_BEEN_LOADED_YET,
      "Aucun état n'a été chargé pour l'instant.")
MSG_HASH(MSG_OVERRIDES_ERROR_SAVING,
      "Erreur lors de l'enregistrement des overrides.")
MSG_HASH(MSG_OVERRIDES_SAVED_SUCCESSFULLY,
      "Les overrides ont été sauvegardés.")
MSG_HASH(MSG_PAUSED,
      "En pause.")
MSG_HASH(MSG_PROGRAM,
      "RetroArch")
MSG_HASH(MSG_READING_FIRST_DATA_TRACK,
      "Lecture de la première piste de données...")
MSG_HASH(MSG_RECEIVED,
      "reçu")
MSG_HASH(MSG_RECORDING_TERMINATED_DUE_TO_RESIZE,
      "Enregistrement interrompu à cause du redimensionnement.")
MSG_HASH(MSG_RECORDING_TO,
      "Enregistrement vers")
MSG_HASH(MSG_REDIRECTING_CHEATFILE_TO,
      "Redirection du fichier triche vers")
MSG_HASH(MSG_REDIRECTING_SAVEFILE_TO,
      "Redirection de la sauvegarde instantanée vers")
MSG_HASH(MSG_REDIRECTING_SAVESTATE_TO,
      "Redirection de la sauvegarde instantanée vers")
MSG_HASH(MSG_REMAP_FILE_SAVED_SUCCESSFULLY,
      "Fichier de remap sauvegardé.")
MSG_HASH(MSG_REMOVED_DISK_FROM_TRAY,
      "Éjection du disque du lecteur.")
MSG_HASH(MSG_REMOVING_TEMPORARY_CONTENT_FILE,
      "Suppression du fichier temporaire")
MSG_HASH(MSG_RESET,
      "Réinitialisation")
MSG_HASH(MSG_RESTARTING_RECORDING_DUE_TO_DRIVER_REINIT,
      "Redémarrage de l'enregistrement à cause de la réinitialisation du pilote.")
MSG_HASH(MSG_RESTORED_OLD_SAVE_STATE,
      "Ancienne sauvegarde instantanée restaurée.")
MSG_HASH(MSG_RESTORING_DEFAULT_SHADER_PRESET_TO,
      "Shaders : restauration du preset de shader par défaut vers")
MSG_HASH(MSG_REVERTING_SAVEFILE_DIRECTORY_TO,
      "Annulation des changements du répertoire de sauvegarde vers")
MSG_HASH(MSG_REVERTING_SAVESTATE_DIRECTORY_TO,
      "Annulation des changements du répertoire de sauvegarde instantanée vers")
MSG_HASH(MSG_REWINDING,
      "Retour rapide.")
MSG_HASH(MSG_REWIND_INIT,
      "Initialisation du tampon pour le retour rapide avec une taille")
MSG_HASH(MSG_REWIND_INIT_FAILED,
      "Échec de l'initialisation du tampon pour le retour rapide. Cette fonctionnalité sera désactivée.")
MSG_HASH(MSG_REWIND_INIT_FAILED_THREADED_AUDIO,
      "L'implémentation utilise audio thread. Impossible d'activer le retour rapide.")
MSG_HASH(MSG_REWIND_REACHED_END,
      "Atteinte de la fin du tampon de retour rapide.")
MSG_HASH(MSG_SAVED_NEW_CONFIG_TO,
      "Nouvelle configuration sauvegardée vers")
MSG_HASH(MSG_SAVED_STATE_TO_SLOT,
      "Sauvegarde instantanée vers l'emplacement #%d.")
MSG_HASH(MSG_SAVED_STATE_TO_SLOT_AUTO,
      "Sauvegarde instantanée vers l'emplacement #-1 (auto).")
MSG_HASH(MSG_SAVED_SUCCESSFULLY_TO,
      "Sauvegarde réussie vers")
MSG_HASH(MSG_SAVING_RAM_TYPE,
      "Sauvegarde du type de RAM")
MSG_HASH(MSG_SAVING_STATE,
      "Sauvegarde instantanée en cours")
MSG_HASH(MSG_SCANNING,
      "Analyse")
MSG_HASH(MSG_SCANNING_OF_DIRECTORY_FINISHED,
      "Analyse des dossiers terminée")
MSG_HASH(MSG_SENDING_COMMAND,
      "Envoi commande")
MSG_HASH(MSG_SEVERAL_PATCHES_ARE_EXPLICITLY_DEFINED,
      "Plusieurs patches sont définis explicitement, ignore tout...")
MSG_HASH(MSG_SHADER,
      "Shader")
MSG_HASH(MSG_SHADER_PRESET_SAVED_SUCCESSFULLY,
      "Preset de shader sauvegardé.")
MSG_HASH(MSG_SKIPPING_SRAM_LOAD,
      "Ignore le chargement de la SRAM.")
MSG_HASH(MSG_SLOW_MOTION,
      "Ralenti.")
MSG_HASH(MSG_FAST_FORWARD,
      "Avance rapide.")
MSG_HASH(MSG_SLOW_MOTION_REWIND,
      "Retour rapide ralenti.")
MSG_HASH(MSG_SRAM_WILL_NOT_BE_SAVED,
      "La SRAM ne sera pas sauvegardée.")
MSG_HASH(MSG_STARTING_MOVIE_PLAYBACK,
      "Démarrage de la lecture vidéo.")
MSG_HASH(MSG_STARTING_MOVIE_RECORD_TO,
      "Démarrage de l'enregistrement vidéo vers")
MSG_HASH(MSG_STATE_SIZE,
      "Taille de la sauvegarde instantanée")
MSG_HASH(MSG_STATE_SLOT,
      "Emplacement de la sauvegarde instantanée")
MSG_HASH(MSG_TAKING_SCREENSHOT,
      "Réalisation d'une copie d'écran.")
MSG_HASH(MSG_TO,
      "de")
MSG_HASH(MSG_UNDID_LOAD_STATE,
      "Chargement de la sauvegarde instantanée annulé.")
MSG_HASH(MSG_UNDOING_SAVE_STATE,
      "Annulation de la sauvegarde instantanée")
MSG_HASH(MSG_UNKNOWN,
      "Inconnu")
MSG_HASH(MSG_UNPAUSED,
      "Relancé.")
MSG_HASH(MSG_UNRECOGNIZED_COMMAND,
      "Commande non reconnue")
MSG_HASH(MSG_USING_CORE_NAME_FOR_NEW_CONFIG,
      "Utilisation du nom du cœur pour la nouvelle configuration.")
MSG_HASH(MSG_USING_LIBRETRO_DUMMY_CORE_RECORDING_SKIPPED,
      "Utilisation d'un core libretro simple. Ignore l'enregistrement.")
MSG_HASH(MSG_VALUE_CONNECT_DEVICE_FROM_A_VALID_PORT,
      "Connecter le périphérique depuis un port valide.")
MSG_HASH(MSG_VALUE_DISCONNECTING_DEVICE_FROM_PORT,
      "Déconnexion du périphérique du port")
MSG_HASH(MSG_VALUE_REBOOTING,
      "Redémarrage...")
MSG_HASH(MSG_VALUE_SHUTTING_DOWN,
      "Extinction en cours...")
MSG_HASH(MSG_VERSION_OF_LIBRETRO_API,
      "Version de l'API libretro")
MSG_HASH(MSG_VIEWPORT_SIZE_CALCULATION_FAILED,
      "Échec du calcul de la taille du visuel ! Utilisation des données brutes. Cela ne fonctionnera probablement pas bien ...")
MSG_HASH(MSG_VIRTUAL_DISK_TRAY,
      "Lecteur de disque virtuel.")
MSG_HASH(MENU_ENUM_SUBLABEL_AUDIO_LATENCY,
      "Latence audio désirée en millisecondes. Peut être ignorée si le pilote audio ne peut fournir une telle valeur.")
MSG_HASH(MENU_ENUM_SUBLABEL_AUDIO_MUTE,
      "Sourdine activée / désactivée.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_RATE_CONTROL_DELTA,
      "Aide à lisser les imperfections de timing lors de la synchronisation audio et vidéo. Attention, si désactivé, une synchronisation correcte est quasiment impossible."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_CAMERA_ALLOW,
      "Autorise ou empêche l'accès à la caméra par les cœurs."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_LOCATION_ALLOW,
      "Autorise ou empêche l'accès aux services de localisation par les cœurs."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_INPUT_MAX_USERS,
      "Nombre maximum d'utilisateurs supportés par RetroArch."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_INPUT_POLL_TYPE_BEHAVIOR,
      "Influence la façon dont le polling des entrées est fait au sein de RetroArch. Le mettre sur 'Tôt' ou 'Tard' peut diminuer la latence, selon la configuration de la machine."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_INPUT_ALL_USERS_CONTROL_MENU,
      "Autorise n'importe quel utilisateur à contrôler le menu. Si désactivé, seul l'utilisateur n°1 peut contrôler le menu."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_VOLUME,
      "Volume sonore (en dB). 0 dB correspond au volume normal, aucun gain n'est appliqué."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_WASAPI_EXCLUSIVE_MODE,
      "Autoriser le pilote WASAPI à prendre le contrôle exclusif du périphérique audio. Si désactivé, le mode partagé sera utilisé."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_WASAPI_FLOAT_FORMAT,
      "Utiliser le format flotant pour WASAPI, si supporté par votre périphérique audio."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_WASAPI_SH_BUFFER_LENGTH,
      "La longueur du tampon intermédiaire (en images) lors de l'utilisation du pilote WASAPI en mode partagé."
      )
MSG_HASH(
   MENU_ENUM_SUBLABEL_AUDIO_SYNC,
   "Synchroniser le son avec le jeu. Recommandé."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_INPUT_AXIS_THRESHOLD,
   "Indique à quel point un axe doit être poussé avant d'obtenir une pression sur un bouton."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_INPUT_BIND_TIMEOUT,
   "Nombre de secondes à attendre avant de passer à l'assignation suivante."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_INPUT_TURBO_PERIOD,
   "Décrit la période après laquelle les boutons turbos s'activent. Les nombres sont décrits en frames."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_INPUT_DUTY_CYCLE,
   "Décrit la durée pendant laquelle un bouton turbo est activé. Les nombres sont décrits en frames."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_VIDEO_VSYNC,
   "Synchronise la sortie vidéo de la carte graphique au taux de rafraîchissement de l'écran. Recommandé."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_VIDEO_ALLOW_ROTATE,
   "Autorise les cœurs à définir la rotation. Lorsque cette option est désactivée, les requêtes de rotation sont ignorées. Utile pour les configurations où il faut tourner l'écran à la main."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_DUMMY_ON_CORE_SHUTDOWN,
   "Certains cœurs ont une fonctionnalité d'extinction. Si activée, cette option empêchera le cœur d'éteindre RetroArch. À la place, il lancera un cœur factice."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_CHECK_FOR_MISSING_FIRMWARE,
   "Vérifie que tous les firmwares requis sont présents avant de tenter de charger le contenu."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_VIDEO_REFRESH_RATE,
   "Rafraîchissement vertical de l'écran. Utilisé pour calculer un taux adapté pour l'entrée audio. NOTE : cette option est ignorée lorsque 'vidéo threadée' est activée."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_AUDIO_ENABLE,
   "Active la sortie audio."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_AUDIO_MAX_TIMING_SKEW,
   "Changement maximal possible du taux de l'entrée audio. Cette valeur peut être augmentée pour autoriser de très grands changements de timing, par exemple pour exécuter un cœur PAL sur un écran NTSC, au prix d'un pitch audio imprécis."
   )
MSG_HASH(
   MSG_FAILED,
   "échec"
   )
MSG_HASH(
   MSG_SUCCEEDED,
   "succès"
   )
MSG_HASH(
   MSG_DEVICE_NOT_CONFIGURED,
   "non configuré"
   )
MSG_HASH(
   MSG_DEVICE_NOT_CONFIGURED_FALLBACK,
   "non configuré, utilisation du fallback"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST,
   "Liste de curseurs de la base de données"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_DEVELOPER,
   "Base de données - Filtre : Développeur"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_PUBLISHER,
   "Base de données - Filtre : Éditeur"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VALUE_DISABLED,
   "Désactivé"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VALUE_ENABLED,
   "Activé"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VALUE_CONTENT_HISTORY_PATH,
   "Patch de l'historique du contenu"
   )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_ORIGIN,
      "Base de données - Filtre : Origine")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_FRANCHISE,
      "Base de données - Filtre : Franchise")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_ESRB_RATING,
      "Base de données - Filtre : Classification ESRB")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_ELSPA_RATING,
      "Base de données - Filtre : Classification ALSPA")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_PEGI_RATING,
      "Base de données - Filtre : Classification PEGI")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_CERO_RATING,
      "Base de données - Filtre : Classification CERO")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_BBFC_RATING,
      "Base de données - Filtre : Classification BBFC")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_MAX_USERS,
      "Base de données - Filtre : Utilisateurs Max")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_RELEASEDATE_BY_MONTH,
      "Base de données - Filtre : Date de sortie Par Mois")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_RELEASEDATE_BY_YEAR,
      "Base de données - Filtre : Date de sortie Par Année")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_EDGE_MAGAZINE_ISSUE,
      "Base de données - Filtre : Numéro du Magazine Edge")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_EDGE_MAGAZINE_RATING,
      "Base de données - Filtre : Note du Magazine Edge")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_DATABASE_INFO,
      "Info Base de données")
MSG_HASH(MSG_WIFI_SCAN_COMPLETE,
      "Scan des réseaux Wi-Fi terminé.")
MSG_HASH(MSG_SCANNING_WIRELESS_NETWORKS,
      "Scan des réseaux Wi-Fi...")
MSG_HASH(MSG_NETPLAY_LAN_SCAN_COMPLETE,
      "Netplay scan complete.")
MSG_HASH(MSG_NETPLAY_LAN_SCANNING,
      "Recherche des hôtes de jeu en réseau...")
MSG_HASH(MENU_ENUM_SUBLABEL_PAUSE_NONACTIVE,
      "Mettre en pause le jeu lorsque le focus de la fenêtre est perdu.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_DISABLE_COMPOSITION,
      "Activer ou désactiver le compositeur (Windows seulement).")
MSG_HASH(MENU_ENUM_SUBLABEL_HISTORY_LIST_ENABLE,
      "Activer ou désactiver l'historique pour les jeux, les images, la musique et les vidéos.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_HISTORY_SIZE,
      "Limiter le nombre d'entrées dans l'historique pour les jeux, les images, la musique et les vidéos.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_UNIFIED_MENU_CONTROLS,
      "Contrôles du menu unifiés")
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_UNIFIED_MENU_CONTROLS,
      "Utiliser les mêmes contrôles à la fois pour le menu et pour le jeu. S'applique au clavier.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_FONT_ENABLE,
      "Afficher les messages à l'écran.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETWORK_USER_REMOTE_ENABLE,
      "Activer la manette réseau pour l'utilisateur %d")
MSG_HASH(MENU_ENUM_LABEL_VALUE_BATTERY_LEVEL_ENABLE,
      "Afficher le niveau de la batterie")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SELECT_FILE,
      "Sélectionner un fichier")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SELECT_FROM_COLLECTION,
      "Sélectionner depuis la collection")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FILTER,
      "Filtre")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SCALE,
      "Zoom")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_START_WHEN_LOADED,
      "Le jeu en réseau débutera quand un contenu sera chargé.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_LOAD_CONTENT_MANUALLY,
      "Impossible de trouver un cœur ou un jeu correspondant, procédez à un chargement manuel.")
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BROWSE_URL_LIST,
      "Parcourir l'URL"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BROWSE_URL,
      "Chemin de l'URL"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BROWSE_START,
      "Démarrer"
      )
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHADER_PIPELINE_BOKEH,
      "Bokeh")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_REFRESH_ROOMS,
      "Rafraîchir la liste des salons")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_ROOM_NICKNAME,
      "Pseudo : %s")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_ROOM_NICKNAME_LAN,
      "Pseudo (lan): %s")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_COMPAT_CONTENT_FOUND,
      "Contenu compatible trouvé")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_CROP_OVERSCAN,
      "Tronque quelques pixels autour de l'image qui étaient souvent inutilisés par les développeurs et peuvent contenir du bruit.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SMOOTH,
      "Applique un léger effet de flou sur l'image pour lisser les pixels. Faible impact sur les performances.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_FILTER,
      "Applique un filtre vidéo qui tourne sur le CPU. NOTE: Peut avoir un coût élevé sur les performances. Certains filtres ne fonctionnent que sur les cœurs utilisant des couleurs 32bit ou 16bit.")
MSG_HASH(MENU_ENUM_SUBLABEL_CHEEVOS_USERNAME,
      "Renseignez l'identifiant de votre compte Retro Achievements.")
MSG_HASH(MENU_ENUM_SUBLABEL_CHEEVOS_PASSWORD,
      "Renseignez le mot de passe de votre compte Retro Achievements.")
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY_NICKNAME,
      "Renseignez votre pseudonyme. Il sera utilisé principalement lors du jeu en réseau.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_POST_FILTER_RECORD,
      "Capturer l'image après que les filtres (mais pas les shaders) aient été appliqués. Votre vidéo sera aussi jolie que ce que vous voyez à l'écran.")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_LIST,
      "Sélectionner le cœur à utiliser.")
MSG_HASH(MENU_ENUM_SUBLABEL_LOAD_CONTENT_LIST,
      "Sélectionner le contenu à démarrer.")
MSG_HASH(MENU_ENUM_SUBLABEL_NETWORK_INFORMATION,
      "Affiche les interfaces réseau et adresses IP associées.")
MSG_HASH(MENU_ENUM_SUBLABEL_SYSTEM_INFORMATION,
      "Affiche les informations spécifique à votre système.")
MSG_HASH(MENU_ENUM_SUBLABEL_QUIT_RETROARCH,
      "Quitter le programe.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_WINDOW_WIDTH,
      "Définir la largeur personalisée de la fenêtre d'affichage. Laisser à 0 pour essayer d'ajuster la largeur de la fenêtre au maximum.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_WINDOW_HEIGHT,
      "Définir la hauteur personalisée de la fenêtre d'affichage. Laisser à 0 pour essayer d'ajuster la hauteur de la fenêtre au maximum.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_FULLSCREEN_X,
      "Définir la largeur personalisée pour le mode plein écran non-fenêtré. Laisser à 0 pour utiliser la résolution du bureau.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_FULLSCREEN_Y,
      "Définir la hauteur personalisée pour le mode plein écran non-fenêtré. Laisser à 0 pour utiliser la résolution du bureau.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_MESSAGE_POS_X,
      "Choisir la position personalisée sur l'axe X pour afficher le texte.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_MESSAGE_POS_Y,
      "Choisir la position personalisée sur l'axe Y pour afficher le texte.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_FONT_SIZE,
      "Spécifier la taille de la police en points.")
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_OVERLAY_HIDE_IN_MENU,
      "Cacher l'overlay quand vous êtes dans le menu. Il sera actif uniquement dans les jeux.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_CONTENT_COLLECTION_LIST,
      "Les contenus scannés apparaitront ici."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_SCALE_INTEGER,
      "Only scales video in integer steps. The base size depends on system-reported geometry and aspect ratio. If 'Force Aspect' is not set, X/Y will be integer scaled independently."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_GPU_SCREENSHOT,
      "Screenshots output of GPU shaded material if available."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_ROTATION,
      "Forcer une rotation de l'écran. Elle sera en supplément d'une autre éventuellement appliquée par le cœur."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_FORCE_SRGB_DISABLE,
      "Forcibly disable sRGB FBO support. Some Intel OpenGL drivers on Windows have video problems with sRGB FBO support if this is enabled. Enabling this can work around it."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_FULLSCREEN,
      "Démarrer en plein écran. Peut être changé à n'importe quel moment."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_WINDOWED_FULLSCREEN,
      "Si plein écran, préférer le mode plein écran fenêtré."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_GPU_RECORD,
      "Records output of GPU shaded material if available."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_SAVESTATE_AUTO_INDEX,
      "When making a savestate, save state index is automatically increased before it is saved. When loading content, the index will be set to the highest existing index."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_BLOCK_SRAM_OVERWRITE,
      "Block Save RAM from being overwritten when loading save states. Might potentially lead to buggy games."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_FASTFORWARD_RATIO,
      "The maximum rate at which content will be run when using fast forward (e.g., 5.0x for 60 fps content = 300 fps cap). If set to 0.0x, fastforward ratio is unlimited (no FPS cap)."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_SLOWMOTION_RATIO,
      "When in slow motion, content will slow down by the factor specified/set."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_REWIND_ENABLE,
      "Activer le retour rapide. Affecte négativement les performances en jeu."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_REWIND_GRANULARITY,
      "When rewinding a defined number of frames, you can rewind several frames at a time, increasing the rewind speed."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_LIBRETRO_LOG_LEVEL,
      "Sets log level for cores. If a log level issued by a core is below this value, it is ignored."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_PERFCNT_ENABLE,
      "Enable performance counters for RetroArch (and cores)."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_SAVESTATE_AUTO_SAVE,
      "Effectuer automatiquement une sauvegarde instantanée à la fin de l'exécution de RetroArch. RetroArch chargera automatiquement la sauvegarde instantanée si 'Charger automatiquement les sauvegardes instantanées' est activé."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_SAVESTATE_AUTO_LOAD,
      "Charger la sauvegarde instantanée automatique au démarrage."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_SAVESTATE_THUMBNAIL_ENABLE,
      "Afficher les miniatures des sauvegardes instantanées dans le menu."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUTOSAVE_INTERVAL,
      "Autosaves the non-volatile Save RAM at a regular interval. This is disabled by default unless set otherwise. The interval is measured in seconds. A value of 0 disables autosave."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_INPUT_REMAP_BINDS_ENABLE,
      "Si activé, remplace la configuration des contrôles par celle du cœur actuel."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_INPUT_AUTODETECT_ENABLE,
      "Activer la détection automatique. Essaiera de configurer les manettes automatiquement de manière Plug-and-Play."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_MENU_INPUT_SWAP_OK_CANCEL,
      "Inverser les boutons OK/Annuler. Désactivé correspond à l'orientation japonaise, Activé à l'orientation occidentale."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_PAUSE_LIBRETRO,
      "Si désactivé, lorsque le menu de RetroArch sera actif il ne suspendra pas le déroulement du contenu en arrière plan."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_DRIVER,
      "Pilote vidéo à utiliser."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_DRIVER,
      "Pilote audio à utiliser."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_INPUT_DRIVER,
      "Pilote d'entrée à utiliser. En fonction du pilote vidéo, celui-ci peut forcer un autre pilote d'entrée."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_JOYPAD_DRIVER,
      "Pilote manette à utiliser."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_RESAMPLER_DRIVER,
      "Pilote de ré-échantillonage audio à utiliser"
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_CAMERA_DRIVER,
      "Pilote de caméra à utiliser."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_LOCATION_DRIVER,
      "Pilote de géolocalisation à utiliser."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_MENU_DRIVER,
      "Pilote de menu, contrôle l'apparence et le comportement du menu."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_RECORD_DRIVER,
      "Pilote d'enregistrement à utiliser."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_WIFI_DRIVER,
      "Pilote Wi-Fi à utiliser."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NAVIGATION_BROWSER_FILTER_SUPPORTED_EXTENSIONS_ENABLE,
      "Filtre les fichiers qui sont visibles dans l'explorateur de fichiers selon les extensions supportées."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_MENU_WALLPAPER,
      "Sélectionner un fond d'écran pour le menu."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_DYNAMIC_WALLPAPER,
      "Afficher un fond d'écran différent pour chaque onglet."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_DEVICE,
      "Override the default audio device the audio driver uses. This is driver dependent."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_DSP_PLUGIN,
      "Audio DSP plugin that processes audio before it's sent to the driver."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_OUTPUT_RATE,
      "Fréquence de la sortie audio."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_OVERLAY_OPACITY,
      "L'opacité globale de l'overlay."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_OVERLAY_SCALE,
      "Échelle globale de l'overlay."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_INPUT_OVERLAY_ENABLE,
      "Activer l'overlay."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_OVERLAY_PRESET,
      "Sélectionner un overlay depuis le navigateur de fichiers."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_IP_ADDRESS,
      "L'adresse IP de l'hôte auquel se connecter."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_TCP_UDP_PORT,
      "Le port de l'adresse IP de l'hôte. Peut être un port TCP ou UDP."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_PASSWORD,
      "Le mot de passe pour se connecter à l'hôte de jeu en réseau. Utilisé seulement en mode hôte."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_PUBLIC_ANNOUNCE,
      "Pour annoncer vos parties en réseau publiquement. Si désactivé, les clients devront se connecter manuellement au lieu de passer par les salons."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_SPECTATE_PASSWORD,
      "Mot de passe pour les spectateurs. Utilisé seulement en mode hôte."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_START_AS_SPECTATOR,
      "Utiliser le mode spectateur pour le jeu en réseau."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_ALLOW_SLAVES,
      "Whether to allow connections in slave mode. Slave-mode clients require very little processing power on either side, but will suffer significantly from network latency."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_REQUIRE_SLAVES,
      "Whether to disallow connections not in slave mode. Not recommended except for very fast networks with very weak machines."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_STATELESS_MODE,
      "Whether to run netplay in a mode not requiring save states. If set to true, a very fast network is required, but no rewinding is performed, so there will be no netplay jitter."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_CHECK_FRAMES,
      "The frequency in frames with which netplay will verify that the host and client are in sync."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_NAT_TRAVERSAL,
      "When hosting, attempt to listen for connections from the public Internet, using UPnP or similar technologies to escape LANs."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_STDIN_CMD_ENABLE,
      "Activer les commandes sur l'entrée standard."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_MOUSE_ENABLE,
      "Pour contrôler le menu à la souris."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_POINTER_ENABLE,
      "Pour contrôler le menu au pavé tactile ou à l'écran tactile."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_THUMBNAILS,
      "Le type de vignettes à afficher."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_TIMEDATE_ENABLE,
      "Affiche la date et l'heure actuelle dans le menu."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_BATTERY_LEVEL_ENABLE,
      "Affiche le niveau de la batterie et si la batterie est en charge dans le menu."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NAVIGATION_WRAPAROUND,
      "Retour du curseur au début ou à la fin de la liste quand les limites sont atteintes."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_ENABLE_HOST,
      "Utiliser le mode hôte (serveur) pour le jeu en réseau."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY_ENABLE_CLIENT,
      "Utiliser le mode client pour le jeu en réseau.")
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY_DISCONNECT,
      "Se déconnecter de la session de jeu en réseau active.")
MSG_HASH(MENU_ENUM_SUBLABEL_SCAN_DIRECTORY,
      "Analyse récursivement un dossier pour y trouver des contenus compatibles qui seront ajoutés dans des playlists.")
MSG_HASH(MENU_ENUM_SUBLABEL_SCAN_FILE,
      "Analyse un fichier pour vérifier s'il est compatible et l'ajouter à une playlist.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SWAP_INTERVAL,
      "Uses a custom swap interval for Vsync. Set this to effectively halve monitor refresh rate."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_SORT_SAVEFILES_ENABLE,
      "Sort save files in folders named after the core used."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_SORT_SAVESTATES_ENABLE,
      "Sort save states in folders named after the core used."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_UPDATER_BUILDBOT_URL,
      "URL to core updater directory on the Libretro buildbot.")
MSG_HASH(MENU_ENUM_SUBLABEL_BUILDBOT_ASSETS_URL,
      "URL to assets updater directory on the Libretro buildbot.")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_UPDATER_AUTO_EXTRACT_ARCHIVE,
      "After downloading, automatically extract files contained in the downloaded archives."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY_REFRESH_ROOMS,
      "Rafraîchir la liste des salons.")
MSG_HASH(MENU_ENUM_SUBLABEL_DELETE_ENTRY,
      "Supprimer cette entrée de la playlist.")
MSG_HASH(MENU_ENUM_SUBLABEL_INFORMATION,
      "En savoir plus sur ce contenu.")
MSG_HASH(MENU_ENUM_SUBLABEL_RUN,
      "Démarrer le contenu.")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_FILE_BROWSER_SETTINGS,
      "Ajuster les réglages du navigateur de fichiers.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUTO_REMAPS_ENABLE,
      "Activer les contrôles personnalisés par défaut au démarrage."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUTO_OVERRIDES_ENABLE,
      "Activer la configuration personnalisée par défaut au démarrage."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_GAME_SPECIFIC_OPTIONS,
      "Activer les options personalisées des cœurs par défaut au démarrage.")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_ENABLE,
      "Affiche le nom du cœur actuel dans le menu.")
MSG_HASH(MENU_ENUM_SUBLABEL_DATABASE_MANAGER,
      "Voir les bases de données.")
MSG_HASH(MENU_ENUM_SUBLABEL_CURSOR_MANAGER,
      "Voir les recherches précédentes.")
MSG_HASH(MENU_ENUM_SUBLABEL_TAKE_SCREENSHOT,
      "Capture une image de l'écran.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_CLOSE_CONTENT,
      "Ferme le contenu actuel. Les changements non sauvegardés peuvent être perdus."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_LOAD_STATE,
      "Charger une sauvegarde instantanée depuis l'emplacement actif.")
MSG_HASH(MENU_ENUM_SUBLABEL_SAVE_STATE,
      "Enregistrer une sauvegarde instantanée dans l'emplacement actif.")
MSG_HASH(MENU_ENUM_SUBLABEL_RESUME,
      "Reprendre le contenu en cours et quitter le menu rapide.")
MSG_HASH(MENU_ENUM_SUBLABEL_RESUME_CONTENT,
      "Reprendre le contenu en cours et quitter le menu rapide.")
MSG_HASH(MENU_ENUM_SUBLABEL_STATE_SLOT,
      "Changer l'emplacement de destination de la sauvegarde instantanée.")
MSG_HASH(MENU_ENUM_SUBLABEL_UNDO_LOAD_STATE,
      "If a state was loaded, content will go back to the state prior to loading.")
MSG_HASH(MENU_ENUM_SUBLABEL_UNDO_SAVE_STATE,
      "If a state was overwritten, it will roll back to the previous save state.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_ACCOUNTS_RETRO_ACHIEVEMENTS,
      "Retro Achievements service. For more information, visit http://retroachievements.org"
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_ACCOUNTS_LIST,
      "Gérer les comptes enregistrés."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_META_REWIND,
      "Gérer les options du retour rapide.")
MSG_HASH(MENU_ENUM_SUBLABEL_RESTART_CONTENT,
      "Redémarrer le contenu.")
MSG_HASH(MENU_ENUM_SUBLABEL_SAVE_CURRENT_CONFIG_OVERRIDE_CORE,
      "Sauvegarde un fichier de configuration qui s'appliquera à tout contenu chargé dorénavant par ce cœur. Prioritaire sur la configuration principale.")
MSG_HASH(MENU_ENUM_SUBLABEL_SAVE_CURRENT_CONFIG_OVERRIDE_GAME,
      "Sauvegarde un fichier de configuration qui s'appliquera uniquement au contenu actuel. Prioritaire sur la configuration principale.")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_CHEAT_OPTIONS,
      "Paramétrer les codes de triche.")
MSG_HASH(MENU_ENUM_SUBLABEL_SHADER_OPTIONS,
      "Paramétrer les shaders pour améliorer l'image.")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_INPUT_REMAPPING_OPTIONS,
      "Modifier les contrôles pour le contenu actuel.")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_OPTIONS,
      "Modifier les options pour le contenu actuel.")
MSG_HASH(MENU_ENUM_SUBLABEL_SHOW_ADVANCED_SETTINGS,
      "Afficher les options avancées pour les utilisateurs expérimentés (invisible par défaut).")
MSG_HASH(MENU_ENUM_SUBLABEL_THREADED_DATA_RUNLOOP_ENABLE,
      "Perform tasks on a separate thread.")
MSG_HASH(MENU_ENUM_SUBLABEL_PLAYLIST_ENTRY_REMOVE,
      "Autoriser l'utilisateur à supprimer des entrées des collections")
MSG_HASH(MENU_ENUM_SUBLABEL_SYSTEM_DIRECTORY,
      "Définir le répertoire système. Les cœur peuvent utiliser ce répertoire pour charger des BIOS, configurations, etc.")
MSG_HASH(MENU_ENUM_SUBLABEL_RGUI_BROWSER_DIRECTORY,
      "Définir le répertoire de début pour l'exporateur de fichiers.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_CONTENT_DIR,
      "Usually set by developers who bundle libretro/RetroArch apps to point to assets."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_DYNAMIC_WALLPAPERS_DIRECTORY,
      "Directory to store wallpapers dynamically loaded by the menu depending on context.")
MSG_HASH(MENU_ENUM_SUBLABEL_THUMBNAILS_DIRECTORY,
      "Supplementary thumbnails (boxarts/misc. images, etc.) are stored here."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_RGUI_CONFIG_DIRECTORY,
      "Sets start directory for menu configuration browser.")
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY_INPUT_LATENCY_FRAMES_MIN,
      "The number of frames of input latency for netplay to use to hide network latency. Reduces jitter and makes netplay less CPU-intensive, at the expense of noticeable input lag.")
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY_INPUT_LATENCY_FRAMES_RANGE,
      "The range of frames of input latency that may be used to hide network latency. Reduces jitter and makes netplay less CPU-intensive, at the expense of unpredictable input lag.")
MSG_HASH(MENU_ENUM_SUBLABEL_DISK_CYCLE_TRAY_STATUS,
      "Cycle the current disk. If the disk is inserted, it will eject the disk. If the disk has not been inserted, it will be inserted. ")
MSG_HASH(MENU_ENUM_SUBLABEL_DISK_INDEX,
      "Change the disk index.")
MSG_HASH(MENU_ENUM_SUBLABEL_DISK_OPTIONS,
      "Disk image management.")
MSG_HASH(MENU_ENUM_SUBLABEL_DISK_IMAGE_APPEND,
      "Select a disk image to insert.")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_ENUM_THROTTLE_FRAMERATE,
      "Makes sure the framerate is capped while inside the menu.")
MSG_HASH(MENU_ENUM_SUBLABEL_XMB_LAYOUT,
      "Select a different layout for the XMB interface.")
MSG_HASH(MENU_ENUM_SUBLABEL_XMB_THEME,
      "Select a different theme for the icon. Changes will take effect after you restart the program.")
MSG_HASH(MENU_ENUM_SUBLABEL_XMB_SHADOWS_ENABLE,
      "Enable drop shadows for all icons. This will have a minor performance hit.")
MSG_HASH(MENU_ENUM_SUBLABEL_MATERIALUI_MENU_COLOR_THEME,
      "Choisir un thème de dégradé de couleur différent pour l'arrière plan.")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_WALLPAPER_OPACITY,
      "Modifier l'opacité de l'image d'arrière plan.")
MSG_HASH(MENU_ENUM_SUBLABEL_XMB_MENU_COLOR_THEME,
      "Choisir un thème de dégradé de couleur différent pour l'arrière plan.")
MSG_HASH(MENU_ENUM_SUBLABEL_XMB_RIBBON_ENABLE,
      "Select an animated background effect. Can be GPU-intensive depending on the effect. If performance is unsatisfactory, either turn this off or revert to a simpler effect.")
MSG_HASH(MENU_ENUM_SUBLABEL_XMB_FONT,
      "Choisir une police principale différente pour le menu.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_IMAGES,
      "Affiche l'onglet des images dans le menu principal.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_MUSIC,
      "Affiche l'onglet des musiques dans le menu principal.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_VIDEO,
      "Affiche l'onglet des vidéos dans le menu principal.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_NETPLAY,
      "Affiche l'onglet de jeu en réseau dans le menu principal.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_SETTINGS,
      "Affiche l'onglet ces réglages dans le menu principal.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_HISTORY,
      "Affiche l'onglet de l'historique dans le menu principal.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_ADD,
      "Show the import content tab inside the main menu.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_PLAYLISTS,
      "Show playlist tabs inside the main menu.")
MSG_HASH(MENU_ENUM_SUBLABEL_RGUI_SHOW_START_SCREEN,
      "Show startup screen in menu. This is automatically set to false after the program starts for the first time.")
MSG_HASH(MENU_ENUM_SUBLABEL_MATERIALUI_MENU_HEADER_OPACITY,
      "Modify the opacity of the header graphic.")
MSG_HASH(MENU_ENUM_SUBLABEL_MATERIALUI_MENU_FOOTER_OPACITY,
      "Modify the opacity of the footer graphic.")
MSG_HASH(MENU_ENUM_SUBLABEL_DPI_OVERRIDE_ENABLE,
      "The menu normally scales itself dynamically. If you want to set a specific scaling size instead, enable this.")
MSG_HASH(MENU_ENUM_SUBLABEL_DPI_OVERRIDE_VALUE,
      "Set the custom scaling size here. NOTE: You have to enable 'DPI Override' for this scaling size to take effect.")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_ASSETS_DIRECTORY,
      "Save all downloaded files to this directory.")
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_REMAPPING_DIRECTORY,
      "Save all remapped controls to this directory.")
MSG_HASH(MENU_ENUM_SUBLABEL_LIBRETRO_DIR_PATH,
      "Directory where the program searches for content/cores.")
MSG_HASH(MENU_ENUM_SUBLABEL_LIBRETRO_INFO_PATH,
      "Application/core information files are stored here.")
MSG_HASH(MENU_ENUM_SUBLABEL_JOYPAD_AUTOCONFIG_DIR,
      "If a joypad is plugged in, that joypad will be autoconfigured if a config file corresponding to it is present inside this directory.")
MSG_HASH(MENU_ENUM_SUBLABEL_PLAYLIST_DIRECTORY,
      "Sauvegarder toutes les collections dans ce dossier.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_CACHE_DIRECTORY,
      "If set to a directory, content which is temporarily extracted (e.g. from archives) will be extracted to this directory."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_CURSOR_DIRECTORY,
      "Saved queries are stored to this directory.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_CONTENT_DATABASE_DIRECTORY,
      "Les bases de données sont stockées dans ce répertoire."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_ASSETS_DIRECTORY,
      "This location is queried by default when menu interfaces try to look for loadable assets, etc."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_SAVEFILE_DIRECTORY,
      "Save all save files to this directory. If not set, will try to save inside the content file's working directory.")
MSG_HASH(MENU_ENUM_SUBLABEL_SAVESTATE_DIRECTORY,
      "Save all save states to this directory. If not set, will try to save inside the content file's working directory.")
MSG_HASH(MENU_ENUM_SUBLABEL_SCREENSHOT_DIRECTORY,
      "Dossier d'emplacement des captures d'écran.")
MSG_HASH(MENU_ENUM_SUBLABEL_OVERLAY_DIRECTORY,
      "Defines a directory where overlays are kept for easy access.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_CHEAT_DATABASE_PATH,
      "Les fichiers de triche sont stockés ici."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_FILTER_DIR,
      "Directory where audio DSP filter files are kept."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_FILTER_DIR,
      "Directory where CPU-based video filter files are kept."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SHADER_DIR,
      "Defines a directory where GPU-based video shader files are kept for easy access.")
MSG_HASH(MENU_ENUM_SUBLABEL_RECORDING_OUTPUT_DIRECTORY,
      "Recordings will be dumped to this directory.")
MSG_HASH(MENU_ENUM_SUBLABEL_RECORDING_CONFIG_DIRECTORY,
      "Recording configurations will be kept here.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_FONT_PATH,
      "Choisir une police différente pour les notifications.")
MSG_HASH(MENU_ENUM_SUBLABEL_SHADER_APPLY_CHANGES,
      "Changes to the shader configuration will take effect immediately. Use this if you changed the amount of shader passes, filtering, FBO scale, etc.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_SHADER_NUM_PASSES,
      "Increase or decrease the amount of shader pipeline passes. You can bind a separate shader to each pipeline pass and configure its scale and filtering."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SHADER_PRESET,
      "Load a shader preset. The shader pipeline will be automatically set-up.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SHADER_PRESET_SAVE_AS,
      "Save the current shader settings as a new shader preset.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SHADER_PRESET_SAVE_CORE,
      "Save the current shader settings as the default settings for this application/core.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SHADER_PRESET_SAVE_GAME,
      "Save the current shader settings as the default settings for the content.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SHADER_PARAMETERS,
      "Modifies the current shader directly. Changes will not be saved to the preset file.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SHADER_PRESET_PARAMETERS,
      "Modifies the shader preset itself currently used in the menu.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_CHEAT_NUM_PASSES,
      "Augmenter ou réduire le nombre de codes de triche."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_CHEAT_APPLY_CHANGES,
      "Cheat changes will take effect immediately.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_CHEAT_FILE_LOAD,
      "Charger un fichier de triche."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_CHEAT_FILE_SAVE_AS,
      "Save current cheats as a save file."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SETTINGS,
      "Accéder rapidement aux options utiles en jeu.")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_INFORMATION,
      "View information pertaining to the application/core.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_ASPECT_RATIO,
      "Floating point value for video aspect ratio (width / height), used if the Aspect Ratio is set to 'Config'.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_VIEWPORT_CUSTOM_HEIGHT,
      "Custom viewport height that is used if the Aspect Ratio is set to 'Custom'.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_VIEWPORT_CUSTOM_WIDTH,
      "Custom viewport width that is used if the Aspect Ratio is set to 'Custom'.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_VIEWPORT_CUSTOM_X,
      "Custom viewport offset used for defining the X-axis position of the viewport. These are ignored if 'Integer Scale' is enabled. It will be automatically centered then.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_VIEWPORT_CUSTOM_Y,
      "Custom viewport offset used for defining the Y-axis position of the viewport. These are ignored if 'Integer Scale' is enabled. It will be automatically centered then.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_USE_MITM_SERVER,
      "Use Relay Server")
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY_USE_MITM_SERVER,
      "Forward netplay connections through a man-in-the-middle server. Useful if the host is behind a firewall or has NAT/UPnP problems.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ADD_TO_MIXER,
      "Ajouter au mixeur")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ADD_TO_MIXER_AND_PLAY,
      "Add to mixer and play")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ADD_TO_MIXER_AND_COLLECTION,
      "Ajouter au mixeur")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ADD_TO_MIXER_AND_COLLECTION_AND_PLAY,
      "Add to mixer and play")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FILTER_BY_CURRENT_CORE,
      "Filter by current core")
MSG_HASH(
      MSG_AUDIO_MIXER_VOLUME,
      "Volume global du mixeur audio"
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_MIXER_VOLUME,
      "Volume global du mixeur audio (en dB). 0 dB est le volume normal sans gain."
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_MIXER_VOLUME,
      "Niveau de volume du mixeur audio (dB)"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_MIXER_MUTE,
      "Rendre muet le mixeur audio"
      )
MSG_HASH(MENU_ENUM_SUBLABEL_AUDIO_MIXER_MUTE,
      "Rendre muet/Activer le mixeur audio.")
MSG_HASH(MENU_ENUM_LABEL_MENU_SHOW_ONLINE_UPDATER,
      "Afficher les mises à jour")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_ONLINE_UPDATER,
      "Afficher/cacher l'option 'mises à jour'.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SHOW_CORE_UPDATER,
      "Afficher les mises à jour des cœurs")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_CORE_UPDATER,
      "Afficher/cacher la possibilité de mettre à jour les cœurs (et les fichiers d'information des cœurs).")
MSG_HASH(MSG_PREPARING_FOR_CONTENT_SCAN,
      "Préparation du scan de contenu...")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_DELETE,
      "Supprimer le cœur")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_DELETE,
      "Supprimer le cœur du disque.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RENAME_ENTRY,
      "Renommer le titre de l'entrée.")
MSG_HASH(MENU_ENUM_LABEL_RENAME_ENTRY,
      "Renommer")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_FRAMEBUFFER_OPACITY,
      "Opacité du framebuffer ")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_FRAMEBUFFER_OPACITY,
      "Modifier l'opacité du framebuffer.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_GOTO_FAVORITES,
      "Favoris")
MSG_HASH(MENU_ENUM_SUBLABEL_GOTO_FAVORITES,
      "Le contenu que vous avez ajouté aux 'Favoris'.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_GOTO_MUSIC,
      "Musique")
MSG_HASH(MENU_ENUM_SUBLABEL_GOTO_MUSIC,
      "La musique écoutée précédemment apparaitra ici.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_GOTO_IMAGES,
      "Image")
MSG_HASH(MENU_ENUM_SUBLABEL_GOTO_IMAGES,
      "Les images vues précédemment apparaitront ici.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_GOTO_VIDEO,
      "Vidéo")
MSG_HASH(MENU_ENUM_SUBLABEL_GOTO_VIDEO,
      "Les vidéos lues précédemment apparaitront ici.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_ICONS_ENABLE,
      "Icônes du menu")
MSG_HASH(MENU_ENUM_SUBLABEL_MATERIALUI_ICONS_ENABLE,
      "Activer/Désactiver les icônes précédant chaque entrée du menu.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MAIN_MENU_ENABLE_SETTINGS,
      "Activer l'onglet des réglages")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_SETTINGS_PASSWORD,
      "Définir le mot de passe pour activer l'onglet des réglages.")
MSG_HASH(MSG_INPUT_ENABLE_SETTINGS_PASSWORD,
      "Entrer le mot de passe")
MSG_HASH(MSG_INPUT_ENABLE_SETTINGS_PASSWORD_OK,
      "Mot de passe correct.")
MSG_HASH(MSG_INPUT_ENABLE_SETTINGS_PASSWORD_NOK,
      "Mot de passe incorrect.")
MSG_HASH(MENU_ENUM_SUBLABEL_XMB_MAIN_MENU_ENABLE_SETTINGS,
      "Active l'onglet des réglages. Un redémarrage est requis pour que l'onglet s'affiche.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_SETTINGS_PASSWORD,
      "Supplying a password when hiding the settings tab makes it possible to later restore it from the menu, by going to the Main Menu tab, selecting Enable Settings Tab and entering the password.")
MSG_HASH(MENU_ENUM_SUBLABEL_PLAYLIST_ENTRY_RENAME,
      "Autoriser l'utilisateur à renommer les entrées des collections.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PLAYLIST_ENTRY_RENAME,
      "Autoriser le renommage des entrées")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SHOW_LOAD_CORE,
      "Show Load Core")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_LOAD_CORE,
      "Show/hide the 'Load Core' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SHOW_LOAD_CONTENT,
      "Show Load Content")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_LOAD_CONTENT,
      "Show/hide the 'Load Content' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SHOW_INFORMATION,
      "Show Information")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_INFORMATION,
      "Show/hide the 'Information' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SHOW_CONFIGURATIONS,
      "Show Configurations")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_CONFIGURATIONS,
      "Show/hide the 'Configurations' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SHOW_HELP,
      "Afficher l'aide")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_HELP,
      "Afficher/cacher l'option 'Afficher l'aide'.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SHOW_QUIT_RETROARCH,
      "Afficher Quitter RetroArch")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_QUIT_RETROARCH,
      "Afficher/cacher l'option 'Quitter RetroArch'.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SHOW_REBOOT,
      "Afficher Redémarrer")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_REBOOT,
      "Afficher/cacher l'option 'Redémarrer'.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_VIEWS_SETTINGS,
      "Menu rapide")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_VIEWS_SETTINGS,
      "Afficher ou cacher des éléments du menu rapide.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_TAKE_SCREENSHOT,
      "Afficher Prendre une capture d'écran")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_TAKE_SCREENSHOT,
      "Afficher/cacher l'option 'Prendre une capture d'écran'.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_SAVE_LOAD_STATE,
      "Afficher Sauver/Charger une sauvegarde instantanée")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_SAVE_LOAD_STATE,
      "Show/hide the options for saving/loading state.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_UNDO_SAVE_LOAD_STATE,
      "Show Undo Save/Load State")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_UNDO_SAVE_LOAD_STATE,
      "Show/hide the options for undoing save/load state.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_ADD_TO_FAVORITES,
      "Show Add to Favorites")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_ADD_TO_FAVORITES,
      "Show/hide the 'Add to Favorites' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_OPTIONS,
      "Show Options")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_OPTIONS,
      "Show/hide the 'Options' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_CONTROLS,
      "Show Controls")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_CONTROLS,
      "Show/hide the 'Controls' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_CHEATS,
      "Show Cheats")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_CHEATS,
      "Show/hide the 'Cheats' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_SHADERS,
      "Show Shaders")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_SHADERS,
      "Show/hide the 'Shaders' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_SAVE_CORE_OVERRIDES,
      "Show Save Core Overrides")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_SAVE_CORE_OVERRIDES,
      "Show/hide the 'Save Core Overrides' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_SAVE_GAME_OVERRIDES,
      "Show Save Game Overrides")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_SAVE_GAME_OVERRIDES,
      "Show/hide the 'Save Game Overrides' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_INFORMATION,
      "Show Information")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_INFORMATION,
      "Show/hide the 'Information' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_DISABLE_KIOSK_MODE,
      "Disable Kiosk Mode")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_DISABLE_KIOSK_MODE,
      "Disables kiosk mode. A restart is required for the change to take full effect.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_ENABLE_KIOSK_MODE,
      "Enable Kiosk Mode")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_ENABLE_KIOSK_MODE,
      "Protects the setup by hiding all configuration related settings.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_KIOSK_MODE_PASSWORD,
      "Set Password For Disabling Kiosk Mode")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_KIOSK_MODE_PASSWORD,
      "Supplying a password when enabling kiosk mode makes it possible to later disable it from the menu, by going to the Main Menu, selecting Disable Kiosk Mode and entering the password.")
MSG_HASH(MSG_INPUT_KIOSK_MODE_PASSWORD,
      "Enter Password")
MSG_HASH(MSG_INPUT_KIOSK_MODE_PASSWORD_OK,
      "Password correct.")
MSG_HASH(MSG_INPUT_KIOSK_MODE_PASSWORD_NOK,
      "Password incorrect.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_AUTOMATICALLY_ADD_CONTENT_TO_PLAYLIST,
      "Ajouter automatiquement le contenu à la playlist")
MSG_HASH(MENU_ENUM_SUBLABEL_AUTOMATICALLY_ADD_CONTENT_TO_PLAYLIST,
      "Scanne automatiquement les contenus chargés et les ajoute aux playlists.")
MSG_HASH(MSG_SCANNING_OF_FILE_FINISHED,
      "Scan du ficher terminé")
MSG_HASH(MENU_ENUM_LABEL_VALUE_AUDIO_RESAMPLER_QUALITY,
      "Qualité du ré-échantilloneur audio")
MSG_HASH(MENU_ENUM_SUBLABEL_AUDIO_RESAMPLER_QUALITY,
      "Lower this value to favor performance/lower latency over audio quality, increase if you want better audio quality at the expense of performance/lower latency.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_STATISTICS_SHOW,
      "Display Statistics")
MSG_HASH(MENU_ENUM_SUBLABEL_STATISTICS_SHOW,
      "Show onscreen technical statistics.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_RGUI_BORDER_FILLER_ENABLE,
      "Enable border filler")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_RGUI_BORDER_FILLER_THICKNESS_ENABLE,
      "Enable border filler thickness")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_RGUI_BACKGROUND_FILLER_THICKNESS_ENABLE,
      "Enable background filler thickness")
MSG_HASH(MENU_ENUM_SUBLABEL_CRT_SWITCH_RESOLUTION, "For 15 kHz CRT displays only. Attempts to use exact core/game resolution and refresh rate.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CRT_SWITCH_RESOLUTION, "CRT SwitchRes") 
MSG_HASH(MENU_ENUM_SUBLABEL_CRT_SWITCH_RESOLUTION_SUPER, "When CRT SwitchRes is enabled, force ultrawide horizontal resolution to minimize mode switching.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CRT_SWITCH_RESOLUTION_SUPER, "CRT Super Resolution") 
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_REWIND,
      "Show Rewind Settings")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_REWIND,
      "Show/hide the Rewind options.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_LATENCY,
      "Show/hide the Latency options.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_LATENCY,
      "Show Latency Settings")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_OVERLAYS,
      "Show/hide the Overlay options.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_OVERLAYS,
      "Show Overlay Settings")
MSG_HASH(MENU_ENUM_LABEL_VALUE_AUDIO_ENABLE_MENU,
      "Enable menu audio")
MSG_HASH(MENU_ENUM_SUBLABEL_AUDIO_ENABLE_MENU,
      "Enable or disable menu sound.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_AUDIO_MIXER_SETTINGS,
      "Mixer Settings")
MSG_HASH(MENU_ENUM_SUBLABEL_AUDIO_MIXER_SETTINGS,
      "View and/or modify audio mixer settings.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_OVERRIDE_OPTIONS,
      "Configuration Override options")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_OVERRIDE_OPTIONS,
      "Options for overriding the global configuration.")
MSG_HASH(MENU_ENUM_SUBLABEL_MIXER_ACTION_PLAY,
      "Will start playback of the audio stream. Once finished, it will remove the current audio stream from memory.")
MSG_HASH(MENU_ENUM_SUBLABEL_MIXER_ACTION_PLAY_LOOPED,
      "Will start playback of the audio stream. Once finished, it will loop and play the track again from the beginning.")
MSG_HASH(MENU_ENUM_SUBLABEL_MIXER_ACTION_PLAY_SEQUENTIAL,
      "Will start playback of the audio stream. Once finished, it will jump to the next audio stream in sequential order and repeat this behavior. Useful as an album playback mode.")
MSG_HASH(MENU_ENUM_SUBLABEL_MIXER_ACTION_STOP,
      "This will stop playback of the audio stream, but not remove it from memory. You can start playing it again by selecting 'Play'.")
MSG_HASH(MENU_ENUM_SUBLABEL_MIXER_ACTION_REMOVE,
      "This will stop playback of the audio stream and remove it entirely from memory.")
MSG_HASH(MENU_ENUM_SUBLABEL_MIXER_ACTION_VOLUME,
      "Adjust the volume of the audio stream.")
MSG_HASH(MENU_ENUM_SUBLABEL_ADD_TO_MIXER,
      "Add this audio track to an available audio stream slot. If no slots are currently available, it will be ignored.")
MSG_HASH(MENU_ENUM_SUBLABEL_ADD_TO_MIXER_AND_PLAY,
      "Add this audio track to an available audio stream slot and play it. If no slots are currently available, it will be ignored.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MIXER_ACTION_PLAY,
      "Play")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MIXER_ACTION_PLAY_LOOPED,
      "Play (Looped)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MIXER_ACTION_PLAY_SEQUENTIAL,
      "Play (Sequential)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MIXER_ACTION_STOP,
      "Stop")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MIXER_ACTION_REMOVE,
      "Remove")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MIXER_ACTION_VOLUME,
      "Volume")
